@@ -1,7 +1,6 @@
 # frozen_string_literal: true
 
 require "abstract_unit"
-require "set"
 
 require "action_dispatch"
 require "active_support/time"
@@ -965,9 +964,7 @@ class BaseTest < ActiveSupport::TestCase
 
   test "notification for process" do
     events = []
-    ActiveSupport::Notifications.subscribe("process.action_mailer") do |*args|
-      events << ActiveSupport::Notifications::Event.new(*args)
-    end
+    ActiveSupport::Notifications.subscribe("process.action_mailer") { |event| events << event }
 
     BaseMailer.welcome(body: "Hello there").deliver_now
 
@@ -982,9 +979,7 @@ class BaseTest < ActiveSupport::TestCase
 
   test "notification for deliver" do
     events = []
-    ActiveSupport::Notifications.subscribe("deliver.action_mailer") do |*args|
-      events << ActiveSupport::Notifications::Event.new(*args)
-    end
+    ActiveSupport::Notifications.subscribe("deliver.action_mailer") { |event| events << event }
 
     BaseMailer.welcome(body: "Hello there").deliver_now
 
