@@ -190,11 +190,7 @@ class PerformActionTest < ActionController::TestCase
     exception = assert_raise AbstractController::ActionNotFound do
       get :ello
     end
-    if exception.respond_to?(:detailed_message)
-      assert_match "Did you mean?", exception.detailed_message
-    else
-      assert_match "Did you mean?", exception.message
-    end
+    assert_match "Did you mean?", exception.detailed_message
   end
 
   def test_action_missing_should_work
@@ -350,3 +346,15 @@ class EmptyUrlOptionsTest < ActionController::TestCase
     end
   end
 end
+
+class BaseTest < ActiveSupport::TestCase
+  def test_included_modules_are_tracked
+    base_content = File.read("#{__dir__}/../../lib/action_controller/base.rb")
+    included_modules = base_content.scan(/(?<=include )[A-Z].*/)
+
+    assert_equal(
+      ActionController::Base::MODULES.map { |m| m.to_s.delete_prefix("ActionController::") },
+      included_modules
+    )
+  end
+end
