@@ -228,10 +228,24 @@ module ActionController
         response.stream.close
       end
 
+      def no_thread_locals
+        tc.assert_nil Thread.current[:setting]
+
+        response.headers["Content-Type"] = "text/event-stream"
+        %w{ hello world }.each do |word|
+          response.stream.write word
+        end
+        response.stream.close
+      end
+
       def isolated_state
         render plain: CurrentState.id.inspect
       end
 
+      def raw_isolated_state
+        render plain: ActiveSupport::IsolatedExecutionState[:raw_isolated_state].inspect
+      end
+
       def with_stale
         render plain: "stale" if stale?(etag: "123", template: false)
       end
@@ -324,9 +338,9 @@ module ActionController
     tests TestController
 
     def assert_stream_closed
-      assert response.stream.closed?, "stream should be closed"
-      assert response.committed?,     "response should be committed"
-      assert response.sent?,          "response should be sent"
+      assert_predicate response.stream, :closed?, "stream should be closed"
+      assert_predicate response, :committed?,     "response should be committed"
+      assert_predicate response, :sent?,          "response should be sent"
     end
 
     def capture_log_output
@@ -344,7 +358,11 @@ module ActionController
       super
 
       def @controller.new_controller_thread(&block)
-        Thread.new(&block)
+        original_new_controller_thread(&block)
+      end
+
+      def @controller.clean_up_thread_locals(*args)
+        original_clean_up_thread_locals(*args)
       end
     end
 
@@ -373,6 +391,19 @@ module ActionController
       assert_match "my.csv", @response.headers["Content-Disposition"]
     end
 
+    def test_send_stream_instrumentation
+      payload = nil
+      subscriber = proc { |event| payload = event.payload }
+
+      ActiveSupport::Notifications.subscribed(subscriber, "send_stream.action_controller") do
+        get :send_stream_with_explicit_content_type
+      end
+
+      assert_equal "sample.csv", payload[:filename]
+      assert_equal "attachment", payload[:disposition]
+      assert_equal "text/csv", payload[:type]
+    end
+
     def test_send_stream_with_options
       get :send_stream_with_options
       assert_equal %[{ name: "David", age: 41 }], @response.body
@@ -417,6 +448,7 @@ module ActionController
       res = get :write_sleep_autoload
       res.each { }
       ActiveSupport::Dependencies.interlock.done_running
+      pass
     end
 
     def test_async_stream
@@ -511,6 +543,34 @@ module ActionController
       assert_stream_closed
     end
 
+    def test_thread_locals_get_reset
+      @controller.tc = self
+
+      Thread.current[:originating_thread] = Thread.current.object_id
+      Thread.current[:setting]            = "aaron"
+
+      get :thread_locals
+
+      Thread.current[:setting] = nil
+
+      get :no_thread_locals
+    end
+
+    def test_isolated_state_get_reset
+      @controller.tc = self
+      ActiveSupport::IsolatedExecutionState[:raw_isolated_state] = "buffy"
+
+      get :raw_isolated_state
+      assert_equal "buffy".inspect, response.body
+      assert_stream_closed
+
+      ActiveSupport::IsolatedExecutionState.clear
+
+      get :isolated_state
+      assert_equal nil.inspect, response.body
+      assert_stream_closed
+    end
+
     def test_live_stream_default_header
       get :default_header
       assert response.headers["Content-Type"]
@@ -551,14 +611,9 @@ module ActionController
     end
 
     def test_exception_callback_when_committed
-      current_threads = Thread.list
-
       capture_log_output do |output|
         get :exception_with_callback, format: "text/event-stream"
 
-        # Wait on the execution of all threads
-        (Thread.list - current_threads).each(&:join)
-
         assert_equal %(data: "500 Internal Server Error"\n\n), response.body
         assert_match "An exception occurred...", output.rewind && output.read
         assert_stream_closed
@@ -608,6 +663,30 @@ module ActionController
     end
   end
 
+  class LiveControllerThreadTest < ActionController::TestCase
+    class TestController < ActionController::Base
+      include ActionController::Live
+
+      def greet
+        response.headers["Content-Type"] = "text/event-stream"
+        %w{ hello world }.each do |word|
+          response.stream.write word
+        end
+        response.stream.close
+      end
+    end
+
+    tests TestController
+
+    def test_thread_locals_do_not_get_reset_in_test_environment
+      Thread.current[:setting] = "aaron"
+
+      get :greet
+
+      assert_equal "aaron", Thread.current[:setting]
+    end
+  end
+
   class BufferTest < ActionController::TestCase
     def test_nil_callback
       buf = ActionController::Live::Buffer.new nil
