@@ -19,7 +19,7 @@ end
 class ActionControllerParametersIntegrationTest < ActionController::TestCase
   tests IntegrationController
 
-  test "parameters can be serialized as yaml" do
+  test "parameters can be serialized as YAML" do
     post :yaml_params, params: { person: { name: "Mjallo!" } }
     expected = <<~YAML
 --- !ruby/object:ActionController::Parameters
@@ -43,7 +43,7 @@ permitted: false
       }
     }
 
-    assert_not_deprecated do
+    assert_not_deprecated(ActionController.deprecator) do
       post :permit_params, params: params
     end
     assert_response :ok
