@@ -84,30 +84,28 @@ module ActionDispatch
     end
 
     test "#source_extracts works with nil backtrace_locations" do
-      exception = begin TOPLEVEL_BINDING.eval "yield"; rescue SyntaxError => ex; ex; end
+      exception = begin eval "class Foo; yield; end"; rescue SyntaxError => ex; ex; end
 
       wrapper = ExceptionWrapper.new(nil, exception)
 
       assert_empty wrapper.source_extracts
     end
 
-    if defined?(ErrorHighlight) && Gem::Version.new(ErrorHighlight::VERSION) >= Gem::Version.new("0.4.0")
-      test "#source_extracts works with error_highlight" do
-        lineno = __LINE__
-        begin
-          1.time
-        rescue NameError => exc
-        end
-
-        wrapper = ExceptionWrapper.new(nil, exc)
-
-        code = {}
-        File.foreach(__FILE__).to_a.drop(lineno - 1).take(6).each_with_index do |line, i|
-          code[lineno + i] = line
-        end
-        code[lineno + 2] = ["          1", ".time", "\n"]
-        assert_equal({ code: code, line_number: lineno + 2 }, wrapper.source_extracts.first)
+    test "#source_extracts works with error_highlight" do
+      lineno = __LINE__
+      begin
+        1.time
+      rescue NameError => exc
       end
+
+      wrapper = ExceptionWrapper.new(nil, exc)
+
+      code = {}
+      File.foreach(__FILE__).to_a.drop(lineno - 1).take(6).each_with_index do |line, i|
+        code[lineno + i] = line
+      end
+      code[lineno + 2] = ["        1", ".time", "\n"]
+      assert_equal({ code: code, line_number: lineno + 2 }, wrapper.source_extracts.first)
     end
 
     test "#application_trace returns traces only from the application" do
@@ -278,35 +276,5 @@ module ActionDispatch
 
       assert_equal true, wrapper.show?(request)
     end
-
-    test "#show? emits a deprecation when show_exceptions is true" do
-      exception = RuntimeError.new("")
-      wrapper = ExceptionWrapper.new(nil, exception)
-
-      env = { "action_dispatch.show_exceptions" => true }
-      request = ActionDispatch::Request.new(env)
-
-      msg = "Setting action_dispatch.show_exceptions to true is deprecated. Set to :all instead."
-      result = assert_deprecated(msg, ActionDispatch.deprecator) do
-        wrapper.show?(request)
-      end
-
-      assert_equal true, result
-    end
-
-    test "#show? emits a deprecation when show_exceptions is false" do
-      exception = RuntimeError.new("")
-      wrapper = ExceptionWrapper.new(nil, exception)
-
-      env = { "action_dispatch.show_exceptions" => false }
-      request = ActionDispatch::Request.new(env)
-
-      msg = "Setting action_dispatch.show_exceptions to false is deprecated. Set to :none instead."
-      result = assert_deprecated(msg, ActionDispatch.deprecator) do
-        wrapper.show?(request)
-      end
-
-      assert_equal false, result
-    end
   end
 end
