@@ -3,6 +3,11 @@
 require "abstract_unit"
 require "action_view/dependency_tracker"
 
+require "action_view/render_parser/prism_render_parser"
+
+require "ripper"
+require "action_view/render_parser/ripper_render_parser"
+
 class NeckbeardTracker
   def self.call(name, template)
     ["foo/#{name}"]
@@ -55,7 +60,7 @@ class DependencyTrackerTest < ActionView::TestCase
   end
 end
 
-# Tests run with both ERBTracker and RipperTracker
+# Tests run with both ERBTracker and RubyTracker
 module SharedTrackerTests
   def test_dependency_of_erb_template_with_number_in_filename
     template = FakeTemplate.new("<%= render 'messages/message123' %>", :erb)
@@ -218,21 +223,56 @@ module SharedTrackerTests
 
     assert_equal ["single/\#{quote}"], tracker.dependencies
   end
-end
 
-class ERBTrackerTest < Minitest::Test
-  include SharedTrackerTests
+  def test_dependencies_with_interpolation_are_resolved_with_view_paths
+    view_paths = ActionView::PathSet.new([File.expand_path("../fixtures/digestor", __dir__)])
 
-  def make_tracker(name, template)
-    ActionView::DependencyTracker::ERBTracker.new(name, template)
+    template = FakeTemplate.new(%q{
+      <%= render "events/#{quote}" %>
+    }, :erb)
+
+    tracker = make_tracker("interpolation/_string", template, view_paths)
+
+    assert_equal ["events/_completed", "events/_event", "events/index"], tracker.dependencies
+  end
+
+  def test_dependencies_with_interpolation_non_trailing
+    view_paths = ActionView::PathSet.new([File.expand_path("../fixtures/digestor", __dir__)])
+
+    template = FakeTemplate.new(%q{
+      <%= render "#{type}/comments" %>
+    }, :erb)
+
+    tracker = make_tracker("interpolation/_string", template, view_paths)
+
+    assert_equal [ "*/comments" ], tracker.dependencies
+  end
+
+  def test_dependencies_with_interpolation_expr
+    view_paths = ActionView::PathSet.new([File.expand_path("../fixtures/digestor", __dir__)])
+
+    template = FakeTemplate.new(%q{
+      <%= render "orders/#{variable || "default"}" %>
+    }, :erb)
+
+    tracker = make_tracker("interpolation/_string", template, view_paths)
+
+    # unsupported
+    assert_equal [], tracker.dependencies
   end
 end
 
-class RipperTrackerTest < Minitest::Test
+class ERBTrackerTest < ActiveSupport::TestCase
   include SharedTrackerTests
 
-  def make_tracker(name, template)
-    ActionView::DependencyTracker::RipperTracker.new(name, template)
+  def make_tracker(name, template, view_paths = nil)
+    ActionView::DependencyTracker::ERBTracker.new(name, template, view_paths)
+  end
+end
+
+module RubyTrackerTests
+  def make_tracker(name, template, view_paths = nil)
+    ActionView::DependencyTracker::RubyTracker.new(name, template, view_paths, parser_class: parser_class)
   end
 
   def test_dependencies_skip_unknown_options
@@ -262,3 +302,21 @@ class RipperTrackerTest < Minitest::Test
     assert_equal [], tracker.dependencies
   end
 end
+
+class RipperRubyTrackerTest < ActiveSupport::TestCase
+  include SharedTrackerTests
+  include RubyTrackerTests
+
+  def parser_class
+    ActionView::RenderParser::RipperRenderParser
+  end
+end
+
+class PrismRubyTrackerTest < ActiveSupport::TestCase
+  include SharedTrackerTests
+  include RubyTrackerTests
+
+  def parser_class
+    ActionView::RenderParser::PrismRenderParser
+  end
+end
