@@ -209,45 +209,49 @@ module RenderTestCases
     end
   end
 
-  if RUBY_VERSION >= "3.2" && RUBY_VERSION < "3.4" # https://github.com/rails/rails/issues/52902
-    def test_render_runtime_error
-      ex = assert_raises(ActionView::Template::Error) {
-        @view.render(template: "test/runtime_error")
-      }
-      erb_btl = ex.backtrace_locations.first
+  def test_render_template_with_syntax_error
+    e = assert_raises(ActionView::Template::Error) { silence_warnings { @view.render(template: "test/syntax_error") } }
+    assert_match %r!syntax!, e.message
+    assert_equal "1:    <%= foo(", e.annotated_source_code[0].strip
+  end
 
-      # Get the spot information from ErrorHighlight
-      translating_frame = ActionDispatch::ExceptionWrapper::SourceMapLocation.new(erb_btl, ex.template)
-      translated_spot = translating_frame.spot(ex.cause)
+  def test_render_runtime_error
+    ex = assert_raises(ActionView::Template::Error) {
+      @view.render(template: "test/runtime_error")
+    }
+    erb_btl = ex.backtrace_locations.first
 
-      assert_equal 6, translated_spot[:first_column]
-    end
+    # Get the spot information from ErrorHighlight
+    translating_frame = ActionDispatch::ExceptionWrapper::SourceMapLocation.new(erb_btl, ex.template)
+    translated_spot = translating_frame.spot(ex.cause)
 
-    def test_render_location_conditional_append
-      ex = assert_raises(ActionView::Template::Error) {
-        @view.render(template: "test/unparseable_runtime_error")
-      }
-      erb_btl = ex.backtrace_locations.first
+    assert_equal 6, translated_spot[:first_column]
+  end
 
-      # Get the spot information from ErrorHighlight
-      translating_frame = ActionDispatch::ExceptionWrapper::SourceMapLocation.new(erb_btl, ex.template)
-      translated_spot = translating_frame.spot(ex.cause)
+  def test_render_location_conditional_append
+    ex = assert_raises(ActionView::Template::Error) {
+      @view.render(template: "test/unparseable_runtime_error")
+    }
+    erb_btl = ex.backtrace_locations.first
 
-      assert_equal 8, translated_spot[:first_column]
-    end
+    # Get the spot information from ErrorHighlight
+    translating_frame = ActionDispatch::ExceptionWrapper::SourceMapLocation.new(erb_btl, ex.template)
+    translated_spot = translating_frame.spot(ex.cause)
 
-    def test_render_location_conditional_append_2
-      ex = assert_raises(ActionView::Template::Error) {
-        @view.render(template: "test/unparseable_runtime_error_2")
-      }
-      erb_btl = ex.backtrace_locations.first
+    assert_equal 8, translated_spot[:first_column]
+  end
 
-      # Get the spot information from ErrorHighlight
-      translating_frame = ActionDispatch::ExceptionWrapper::SourceMapLocation.new(erb_btl, ex.template)
-      translated_spot = translating_frame.spot(ex.cause)
+  def test_render_location_conditional_append_2
+    ex = assert_raises(ActionView::Template::Error) {
+      @view.render(template: "test/unparseable_runtime_error_2")
+    }
+    erb_btl = ex.backtrace_locations.first
 
-      assert_instance_of Integer, translated_spot[:first_column]
-    end
+    # Get the spot information from ErrorHighlight
+    translating_frame = ActionDispatch::ExceptionWrapper::SourceMapLocation.new(erb_btl, ex.template)
+    translated_spot = translating_frame.spot(ex.cause)
+
+    assert_instance_of Integer, translated_spot[:first_column]
   end
 
   def test_render_partial
@@ -294,8 +298,32 @@ module RenderTestCases
   end
 
   def test_render_partial_with_incompatible_object
-    e = assert_raises(ArgumentError) { @view.render(partial: nil) }
-    assert_equal "'#{nil.inspect}' is not an ActiveModel-compatible object. It must implement :to_partial_path.", e.message
+    assert_raises ArgumentError, match: "'#{nil.inspect}' is not an ActiveModel-compatible object. It must implement #to_partial_path." do
+      @view.render(partial: nil)
+    end
+  end
+
+  def test_render_renderable_with_nil
+    assert_raises ArgumentError, match: "'#{nil.inspect}' is not a renderable object. It must implement #render_in." do
+      @view.render renderable: nil
+    end
+  end
+
+  def test_render_renderable_with_incompatible_object
+    object = Object.new
+
+    assert_raises ArgumentError, match: "'#{object.inspect}' is not a renderable object. It must implement #render_in." do
+      @view.render renderable: object
+    end
+  end
+
+  def test_render_renderable_does_not_mask_nomethoderror_from_within_render_in
+    renderable = Object.new
+    renderable.define_singleton_method(:render_in) { |*| nil.render_in }
+
+    assert_raises NoMethodError, match: /undefined method [`']render_in' for nil/ do
+      @view.render renderable: renderable
+    end
   end
 
   def test_render_partial_starting_with_a_capital
@@ -324,21 +352,13 @@ module RenderTestCases
       "and is followed by any combination of letters, numbers and underscores.", e.message
   end
 
-  def test_render_template_with_syntax_error
-    e = assert_raises(ActionView::Template::Error) { @view.render(template: "test/syntax_error") }
-    assert_match %r!syntax!, e.message
-    assert_equal "1:    <%= foo(", e.annotated_source_code[0].strip
-  end
-
-  if RUBY_VERSION < "3.4" # https://github.com/rails/rails/issues/52902
-    def test_render_partial_with_errors
-      e = assert_raises(ActionView::Template::Error) { @view.render(partial: "test/raise") }
-      assert_match %r!method.*doesnt_exist!, e.message
-      assert_equal "", e.sub_template_message
-      assert_equal "1", e.line_number
-      assert_equal "1: <%= doesnt_exist %>", e.annotated_source_code[0].strip
-      assert_equal File.expand_path("#{FIXTURE_LOAD_PATH}/test/_raise.html.erb"), e.file_name
-    end
+  def test_render_partial_with_errors
+    e = assert_raises(ActionView::Template::Error) { @view.render(partial: "test/raise") }
+    assert_match %r!method.*doesnt_exist!, e.message
+    assert_equal "", e.sub_template_message
+    assert_equal "1", e.line_number
+    assert_equal "1: <%= doesnt_exist %>", e.annotated_source_code[0].strip
+    assert_equal File.expand_path("#{FIXTURE_LOAD_PATH}/test/_raise.html.erb"), e.file_name
   end
 
   def test_render_error_indentation
@@ -378,6 +398,11 @@ module RenderTestCases
     assert_equal "NilClass", @view.render(partial: "test/klass", object: nil)
   end
 
+  def test_render_renderable_render_in
+    assert_equal "Hello, World!", @view.render(TestRenderable.new)
+    assert_equal "Hello, World!", @view.render(renderable: TestRenderable.new)
+  end
+
   def test_render_object_different_name
     assert_equal "Hello: t.lo", @view.render(partial: "test/template_not_named_customer", object: Customer.new("t.lo"), as: "customer").chomp
   end
@@ -682,55 +707,32 @@ module RenderTestCases
 
   def test_render_partial_provides_spellcheck
     e = assert_raises(ActionView::MissingTemplate) { @view.render(partial: "test/partail") }
-    if e.respond_to?(:detailed_message)
-      assert_match %r{Did you mean\?  test/partial\e\[m\n\e\[1m *test/partialhtml}, e.detailed_message
-    else
-      assert_match %r{Did you mean\?  test/partial\n *test/partialhtml}, e.message
-    end
+    assert_match %r{Did you mean\?  test/partial\e\[m\n\e\[1m *test/partialhtml}, e.detailed_message
   end
 
   def test_spellcheck_doesnt_list_directories
     e = assert_raises(ActionView::MissingTemplate) { @view.render(partial: "test/directory") }
-    if e.respond_to?(:detailed_message)
-      assert_match %r{Did you mean\?}, e.detailed_message
-      assert_no_match %r{Did you mean\?  test/directory\n}, e.detailed_message # test/hello is a directory
-    else
-      assert_match %r{Did you mean\?}, e.message
-      assert_no_match %r{Did you mean\?  test/directory\n}, e.message # test/hello is a directory
-    end
+    assert_match %r{Did you mean\?}, e.detailed_message
+    assert_no_match %r{Did you mean\?  test/directory\n}, e.detailed_message # test/hello is a directory
   end
 
   def test_spellcheck_only_lists_templates
     e = assert_raises(ActionView::MissingTemplate) { @view.render(template: "test/partial") }
 
-    if e.respond_to?(:detailed_message)
-      assert_match %r{Did you mean\?}, e.detailed_message
-      assert_no_match %r{Did you mean\?  test/partial\n}, e.detailed_message
-    else
-      assert_match %r{Did you mean\?}, e.message
-      assert_no_match %r{Did you mean\?  test/partial\n}, e.message
-    end
+    assert_match %r{Did you mean\?}, e.detailed_message
+    assert_no_match %r{Did you mean\?  test/partial\n}, e.detailed_message
   end
 
   def test_spellcheck_only_lists_partials
     e = assert_raises(ActionView::MissingTemplate) { @view.render(partial: "test/template") }
 
-    if e.respond_to?(:detailed_message)
-      assert_match %r{Did you mean\?}, e.detailed_message
-      assert_no_match %r{Did you mean\?  test/template\n}, e.detailed_message
-    else
-      assert_match %r{Did you mean\?}, e.message
-      assert_no_match %r{Did you mean\?  test/template\n}, e.message
-    end
+    assert_match %r{Did you mean\?}, e.detailed_message
+    assert_no_match %r{Did you mean\?  test/template\n}, e.detailed_message
   end
 
   def test_render_partial_wrong_details_no_spellcheck
     e = assert_raises(ActionView::MissingTemplate) { @view.render(partial: "test/partial_with_only_html_version", formats: [:xml]) }
-    if e.respond_to?(:detailed_message)
-      assert_no_match %r{Did you mean\?}, e.detailed_message
-    else
-      assert_no_match %r{Did you mean\?}, e.message
-    end
+    assert_no_match %r{Did you mean\?}, e.detailed_message
   end
 
   def test_render_with_nested_layout
@@ -767,7 +769,7 @@ module RenderTestCases
   end
 
   def test_render_mutate_string_literal
-    assert_equal "foobar", @view.render(inline: "'foo' << 'bar'", type: :ruby)
+    assert_equal "foobar", @view.render(inline: "+'foo' << 'bar'", type: :ruby)
   end
 end
 
