@@ -16,17 +16,21 @@ module ActiveRecord
       end
 
       def setup
-        @conn = Base.sqlite3_connection database: ":memory:",
-                                        adapter: "sqlite3",
-                                        timeout: 100
+        @conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          timeout: 100,
+        )
       end
 
-      def test_bad_connection
-        error = assert_raise ActiveRecord::NoDatabaseError do
-          connection = ActiveRecord::Base.sqlite3_connection(adapter: "sqlite3", database: "/tmp/should/_not/_exist/-cinco-dog.db")
+      def test_database_should_get_created_when_missing_parent_directories_for_database_path
+        dir = Dir.mktmpdir
+        db_path = File.join(dir, "_not_exist/-cinco-dog.sqlite3")
+        assert_nothing_raised do
+          connection = SQLite3Adapter.new(adapter: "sqlite3", database: db_path)
           connection.drop_table "ex", if_exists: true
         end
-        assert_kind_of ActiveRecord::ConnectionAdapters::NullPool, error.connection_pool
+        assert SQLite3Adapter.database_exists?(adapter: "sqlite3", database: db_path)
       end
 
       def test_database_exists_returns_false_when_the_database_does_not_exist
@@ -46,7 +50,7 @@ module ActiveRecord
           tf = Tempfile.open "whatever"
           url = "sqlite3:#{tf.path}"
           ActiveRecord::Base.establish_connection(url)
-          assert ActiveRecord::Base.connection
+          assert ActiveRecord::Base.lease_connection
         ensure
           tf.close
           tf.unlink
@@ -57,7 +61,7 @@ module ActiveRecord
           original_connection = ActiveRecord::Base.remove_connection
           url = "sqlite3::memory:"
           ActiveRecord::Base.establish_connection(url)
-          assert ActiveRecord::Base.connection
+          assert ActiveRecord::Base.lease_connection
         ensure
           ActiveRecord::Base.establish_connection(original_connection)
         end
@@ -72,7 +76,7 @@ module ActiveRecord
         owner = Owner.create!(name: "hello".encode("ascii-8bit"))
         owner.reload
         select = Owner.columns.map { |c| "typeof(#{c.name})" }.join ", "
-        result = Owner.connection.exec_query <<~SQL
+        result = Owner.lease_connection.exec_query <<~SQL
           SELECT #{select}
           FROM   #{Owner.table_name}
           WHERE  #{Owner.primary_key} = #{owner.id}
@@ -117,15 +121,17 @@ module ActiveRecord
 
       def test_connection_no_db
         assert_raises(ArgumentError) do
-          Base.sqlite3_connection({})
+          SQLite3Adapter.new({})
         end
       end
 
       def test_bad_timeout
         exception = assert_raises(ActiveRecord::StatementInvalid) do
-          Base.sqlite3_connection(database: ":memory:",
-                                  adapter: "sqlite3",
-                                  timeout: "usa").connect!
+          SQLite3Adapter.new(
+            database: ":memory:",
+            adapter: "sqlite3",
+            timeout: "usa",
+          ).connect!
         end
         assert_match("TypeError", exception.message)
         assert_kind_of ActiveRecord::ConnectionAdapters::NullPool, exception.connection_pool
@@ -133,9 +139,11 @@ module ActiveRecord
 
       # connection is OK with a nil timeout
       def test_nil_timeout
-        conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3",
-                                       timeout: nil
+        conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          timeout: nil,
+        )
         conn.connect!
         assert conn, "made a connection"
       end
@@ -153,7 +161,7 @@ module ActiveRecord
         if in_memory_db?
           assert_equal [{ "foreign_keys" => 1 }], @conn.execute("PRAGMA foreign_keys")
           assert_equal [{ "journal_mode" => "memory" }], @conn.execute("PRAGMA journal_mode")
-          assert_equal [{ "synchronous" => 2 }], @conn.execute("PRAGMA synchronous")
+          assert_equal [{ "synchronous" => 1 }], @conn.execute("PRAGMA synchronous")
           assert_equal [{ "journal_size_limit" => 67108864 }], @conn.execute("PRAGMA journal_size_limit")
           assert_equal [], @conn.execute("PRAGMA mmap_size")
           assert_equal [{ "cache_size" => 2000 }], @conn.execute("PRAGMA cache_size")
@@ -169,6 +177,249 @@ module ActiveRecord
         end
       end
 
+      def test_overriding_default_foreign_keys_pragma
+        method_name = in_memory_db? ? :with_memory_connection : :with_file_connection
+
+        send(method_name, pragmas: { foreign_keys: false }) do |conn|
+          assert_equal [{ "foreign_keys" => 0 }], conn.execute("PRAGMA foreign_keys")
+        end
+
+        send(method_name, pragmas: { foreign_keys: 0 }) do |conn|
+          assert_equal [{ "foreign_keys" => 0 }], conn.execute("PRAGMA foreign_keys")
+        end
+
+        send(method_name, pragmas: { foreign_keys: "false" }) do |conn|
+          assert_equal [{ "foreign_keys" => 0 }], conn.execute("PRAGMA foreign_keys")
+        end
+
+        error = assert_raises(ActiveRecord::StatementInvalid) do
+          send(method_name, pragmas: { foreign_keys: :false }) do |conn|
+            conn.execute("PRAGMA foreign_keys")
+          end
+        end
+        assert_match(/unrecognized pragma parameter :false/, error.message)
+      end
+
+      def test_overriding_default_journal_mode_pragma
+        # in-memory databases are always only ever in `memory` journal_mode
+        if in_memory_db?
+          with_memory_connection(pragmas: { "journal_mode" => "delete" }) do |conn|
+            assert_equal [{ "journal_mode" => "memory" }], conn.execute("PRAGMA journal_mode")
+          end
+
+          with_memory_connection(pragmas: { "journal_mode" => :delete }) do |conn|
+            assert_equal [{ "journal_mode" => "memory" }], conn.execute("PRAGMA journal_mode")
+          end
+
+          error = assert_raises(ActiveRecord::StatementInvalid) do
+            with_memory_connection(pragmas: { "journal_mode" => 0 }) do |conn|
+              conn.execute("PRAGMA journal_mode")
+            end
+          end
+          assert_match(/nrecognized journal_mode 0/, error.message)
+
+          error = assert_raises(ActiveRecord::StatementInvalid) do
+            with_memory_connection(pragmas: { "journal_mode" => false }) do |conn|
+              conn.execute("PRAGMA journal_mode")
+            end
+          end
+          assert_match(/nrecognized journal_mode false/, error.message)
+        else
+          # must use a new, separate database file that hasn't been opened in WAL mode before
+          Dir.mktmpdir do |tmpdir|
+            database_file = File.join(tmpdir, "journal_mode_test.sqlite3")
+
+            with_file_connection(database: database_file, pragmas: { "journal_mode" => "delete" }) do |conn|
+              assert_equal [{ "journal_mode" => "delete" }], conn.execute("PRAGMA journal_mode")
+            end
+
+            with_file_connection(database: database_file, pragmas: { "journal_mode" => :delete }) do |conn|
+              assert_equal [{ "journal_mode" => "delete" }], conn.execute("PRAGMA journal_mode")
+            end
+
+            error = assert_raises(ActiveRecord::StatementInvalid) do
+              with_file_connection(database: database_file, pragmas: { "journal_mode" => 0 }) do |conn|
+                conn.execute("PRAGMA journal_mode")
+              end
+            end
+            assert_match(/unrecognized journal_mode 0/, error.message)
+
+            error = assert_raises(ActiveRecord::StatementInvalid) do
+              with_file_connection(database: database_file, pragmas: { "journal_mode" => false }) do |conn|
+                conn.execute("PRAGMA journal_mode")
+              end
+            end
+            assert_match(/unrecognized journal_mode false/, error.message)
+          end
+        end
+      end
+
+      def test_overriding_default_synchronous_pragma
+        method_name = in_memory_db? ? :with_memory_connection : :with_file_connection
+
+        send(method_name, pragmas: { synchronous: :full }) do |conn|
+          assert_equal [{ "synchronous" => 2 }], conn.execute("PRAGMA synchronous")
+        end
+
+        send(method_name, pragmas: { synchronous: 2 }) do |conn|
+          assert_equal [{ "synchronous" => 2 }], conn.execute("PRAGMA synchronous")
+        end
+
+        send(method_name, pragmas: { synchronous: "full" }) do |conn|
+          assert_equal [{ "synchronous" => 2 }], conn.execute("PRAGMA synchronous")
+        end
+
+        error = assert_raises(ActiveRecord::StatementInvalid) do
+          send(method_name, pragmas: { synchronous: false }) do |conn|
+            conn.execute("PRAGMA synchronous")
+          end
+        end
+        assert_match(/unrecognized synchronous false/, error.message)
+      end
+
+      def test_overriding_default_journal_size_limit_pragma
+        method_name = in_memory_db? ? :with_memory_connection : :with_file_connection
+
+        send(method_name, pragmas: { journal_size_limit: 100 }) do |conn|
+          assert_equal [{ "journal_size_limit" => 100 }], conn.execute("PRAGMA journal_size_limit")
+        end
+
+        send(method_name, pragmas: { journal_size_limit: "200" }) do |conn|
+          assert_equal [{ "journal_size_limit" => 200 }], conn.execute("PRAGMA journal_size_limit")
+        end
+
+        error = assert_raises(ActiveRecord::StatementInvalid) do
+          send(method_name, pragmas: { journal_size_limit: false }) do |conn|
+            conn.execute("PRAGMA journal_size_limit")
+          end
+        end
+        assert_match(/undefined method [`']to_i'/, error.message)
+
+        error = assert_raises(ActiveRecord::StatementInvalid) do
+          send(method_name, pragmas: { journal_size_limit: :false }) do |conn|
+            conn.execute("PRAGMA journal_size_limit")
+          end
+        end
+        assert_match(/undefined method [`']to_i'/, error.message)
+      end
+
+      def test_overriding_default_mmap_size_pragma
+        # in-memory databases never have an mmap_size
+        if in_memory_db?
+          with_memory_connection(pragmas: { mmap_size: 100 }) do |conn|
+            assert_equal [], conn.execute("PRAGMA mmap_size")
+          end
+
+          with_memory_connection(pragmas: { mmap_size: "200" }) do |conn|
+            assert_equal [], conn.execute("PRAGMA mmap_size")
+          end
+
+          error = assert_raises(ActiveRecord::StatementInvalid) do
+            with_memory_connection(pragmas: { mmap_size: false }) do |conn|
+              conn.execute("PRAGMA mmap_size")
+            end
+          end
+          assert_match(/undefined method [`']to_i'/, error.message)
+
+          error = assert_raises(ActiveRecord::StatementInvalid) do
+            with_memory_connection(pragmas: { mmap_size: :false }) do |conn|
+              conn.execute("PRAGMA mmap_size")
+            end
+          end
+          assert_match(/undefined method [`']to_i'/, error.message)
+        else
+          with_file_connection(pragmas: { mmap_size: 100 }) do |conn|
+            assert_equal [{ "mmap_size" => 100 }], conn.execute("PRAGMA mmap_size")
+          end
+
+          with_file_connection(pragmas: { mmap_size: "200" }) do |conn|
+            assert_equal [{ "mmap_size" => 200 }], conn.execute("PRAGMA mmap_size")
+          end
+
+          error = assert_raises(ActiveRecord::StatementInvalid) do
+            with_file_connection(pragmas: { mmap_size: false }) do |conn|
+              conn.execute("PRAGMA mmap_size")
+            end
+          end
+          assert_match(/undefined method [`']to_i'/, error.message)
+
+          error = assert_raises(ActiveRecord::StatementInvalid) do
+            with_file_connection(pragmas: { mmap_size: :false }) do |conn|
+              conn.execute("PRAGMA mmap_size")
+            end
+          end
+          assert_match(/undefined method [`']to_i'/, error.message)
+        end
+      end
+
+      def test_overriding_default_cache_size_pragma
+        method_name = in_memory_db? ? :with_memory_connection : :with_file_connection
+
+        send(method_name, pragmas: { cache_size: 100 }) do |conn|
+          assert_equal [{ "cache_size" => 100 }], conn.execute("PRAGMA cache_size")
+        end
+
+        send(method_name, pragmas: { cache_size: "200" }) do |conn|
+          assert_equal [{ "cache_size" => 200 }], conn.execute("PRAGMA cache_size")
+        end
+
+        error = assert_raises(ActiveRecord::StatementInvalid) do
+          send(method_name, pragmas: { cache_size: false }) do |conn|
+            conn.execute("PRAGMA cache_size")
+          end
+        end
+        assert_match(/undefined method [`']to_i'/, error.message)
+
+        error = assert_raises(ActiveRecord::StatementInvalid) do
+          send(method_name, pragmas: { cache_size: :false }) do |conn|
+            conn.execute("PRAGMA cache_size")
+          end
+        end
+        assert_match(/undefined method [`']to_i'/, error.message)
+      end
+
+      def test_setting_new_pragma
+        if in_memory_db?
+          with_memory_connection(pragmas: { temp_store: :memory }) do |conn|
+            assert_equal [{ "foreign_keys" => 1 }], conn.execute("PRAGMA foreign_keys")
+            assert_equal [{ "journal_mode" => "memory" }], conn.execute("PRAGMA journal_mode")
+            assert_equal [{ "synchronous" => 1 }], conn.execute("PRAGMA synchronous")
+            assert_equal [{ "journal_size_limit" => 67108864 }], conn.execute("PRAGMA journal_size_limit")
+            assert_equal [], conn.execute("PRAGMA mmap_size")
+            assert_equal [{ "cache_size" => 2000 }], conn.execute("PRAGMA cache_size")
+            assert_equal [{ "temp_store" => 2 }], conn.execute("PRAGMA temp_store")
+          end
+        else
+          with_file_connection(pragmas: { temp_store: :memory }) do |conn|
+            assert_equal [{ "foreign_keys" => 1 }], conn.execute("PRAGMA foreign_keys")
+            assert_equal [{ "journal_mode" => "wal" }], conn.execute("PRAGMA journal_mode")
+            assert_equal [{ "synchronous" => 1 }], conn.execute("PRAGMA synchronous")
+            assert_equal [{ "journal_size_limit" => 67108864 }], conn.execute("PRAGMA journal_size_limit")
+            assert_equal [{ "mmap_size" => 134217728 }], conn.execute("PRAGMA mmap_size")
+            assert_equal [{ "cache_size" => 2000 }], conn.execute("PRAGMA cache_size")
+            assert_equal [{ "temp_store" => 2 }], conn.execute("PRAGMA temp_store")
+          end
+        end
+      end
+
+      def test_setting_invalid_pragma
+        if in_memory_db?
+          warning = capture(:stderr) do
+            with_memory_connection(pragmas: { invalid: true }) do |conn|
+              conn.execute("PRAGMA foreign_keys")
+            end
+          end
+          assert_match(/Unknown SQLite pragma: invalid/, warning)
+        else
+          warning = capture(:stderr) do
+            with_file_connection(pragmas: { invalid: true }) do |conn|
+              conn.execute("PRAGMA foreign_keys")
+            end
+          end
+          assert_match(/Unknown SQLite pragma: invalid/, warning)
+        end
+      end
+
       def test_exec_no_binds
         with_example_table "id int, data string" do
           result = @conn.exec_query("SELECT id, data FROM ex")
@@ -213,7 +464,7 @@ module ActiveRecord
       end
 
       def test_quote_binary_column_escapes_it
-        DualEncoding.connection.execute(<<~SQL)
+        DualEncoding.lease_connection.execute(<<~SQL)
           CREATE TABLE IF NOT EXISTS dual_encodings (
             id integer PRIMARY KEY AUTOINCREMENT,
             name varchar(255),
@@ -225,7 +476,7 @@ module ActiveRecord
         binary.save!
         assert_equal str, binary.data
       ensure
-        DualEncoding.connection.drop_table "dual_encodings", if_exists: true
+        DualEncoding.lease_connection.drop_table "dual_encodings", if_exists: true
       end
 
       def test_type_cast_should_not_mutate_encoding
@@ -248,20 +499,15 @@ module ActiveRecord
         end
       end
 
-      def test_quote_string
-        assert_equal "''", @conn.quote_string("'")
-      end
-
       def test_insert_logged
         with_example_table do
           sql = "INSERT INTO ex (number) VALUES (10)"
           name = "foo"
 
-          sqlite_version_query = ["SELECT sqlite_version(*)", "SCHEMA", []]
-          pragma_query = ["PRAGMA table_info(\"ex\")", "SCHEMA", []]
+          pragma_query = ["PRAGMA table_xinfo(\"ex\")", "SCHEMA", []]
           schema_query = ["SELECT sql FROM (SELECT * FROM sqlite_master UNION ALL SELECT * FROM sqlite_temp_master) WHERE type = 'table' AND name = 'ex'", "SCHEMA", []]
           modified_insert_query = [(sql + ' RETURNING "id"'), name, []]
-          assert_logged [sqlite_version_query, pragma_query, schema_query, modified_insert_query] do
+          assert_logged [pragma_query, schema_query, modified_insert_query] do
             @conn.insert(sql, name)
           end
         end
@@ -278,9 +524,11 @@ module ActiveRecord
 
       def test_exec_insert_with_returning_disabled
         original_conn = @conn
-        @conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3",
-                                       insert_returning: false
+        @conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          insert_returning: false,
+        )
         with_example_table do
           result = @conn.exec_insert("insert into ex (number) VALUES ('foo')", nil, [], "id")
           expect = @conn.query("select max(id) from ex").first.first
@@ -291,9 +539,11 @@ module ActiveRecord
 
       def test_exec_insert_default_values_with_returning_disabled
         original_conn = @conn
-        @conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3",
-                                       insert_returning: false
+        @conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          insert_returning: false,
+        )
         with_example_table do
           result = @conn.exec_insert("insert into ex DEFAULT VALUES", nil, [], "id")
           expect = @conn.query("select max(id) from ex").first.first
@@ -346,7 +596,7 @@ module ActiveRecord
 
       def test_tables_logs_name
         sql = <<~SQL
-          SELECT name FROM sqlite_master WHERE name <> 'sqlite_sequence' AND type IN ('table')
+          SELECT name FROM pragma_table_list WHERE schema <> 'temp' AND name NOT IN ('sqlite_sequence', 'sqlite_schema') AND type IN ('table')
         SQL
         @conn.connect!
         assert_logged [[sql.squish, "SCHEMA", []]] do
@@ -357,7 +607,7 @@ module ActiveRecord
       def test_table_exists_logs_name
         with_example_table do
           sql = <<~SQL
-            SELECT name FROM sqlite_master WHERE name <> 'sqlite_sequence' AND name = 'ex' AND type IN ('table')
+            SELECT name FROM pragma_table_list WHERE schema <> 'temp' AND name NOT IN ('sqlite_sequence', 'sqlite_schema') AND name = 'ex' AND type IN ('table')
           SQL
           assert_logged [[sql.squish, "SCHEMA", []]] do
             assert @conn.table_exists?("ex")
@@ -448,7 +698,16 @@ module ActiveRecord
         end
       end
 
-      if ActiveRecord::Base.connection.supports_expression_index?
+      def test_partial_index_with_comment
+        with_example_table do
+          @conn.add_index "ex", :id, name: "fun", where: "number > 0 /*tag:test*/"
+          index = @conn.indexes("ex").find { |idx| idx.name == "fun" }
+          assert_equal ["id"], index.columns
+          assert_equal "number > 0", index.where
+        end
+      end
+
+      if ActiveRecord::Base.lease_connection.supports_expression_index?
         def test_expression_index
           with_example_table do
             @conn.add_index "ex", "max(id, number)", name: "expression"
@@ -515,7 +774,7 @@ module ActiveRecord
       end
 
       def test_copy_table_with_existing_records_have_custom_primary_key
-        connection = BarcodeCustomPk.connection
+        connection = BarcodeCustomPk.lease_connection
         connection.create_table(:barcode_custom_pks, primary_key: "code", id: :string, limit: 42, force: true) do |t|
           t.text :other_attr
         end
@@ -534,7 +793,7 @@ module ActiveRecord
       end
 
       def test_copy_table_with_composite_primary_keys
-        connection = BarcodeCpk.connection
+        connection = BarcodeCpk.lease_connection
         connection.create_table(:barcode_cpks, primary_key: ["region", "code"], force: true) do |t|
           t.string :region
           t.string :code
@@ -556,7 +815,7 @@ module ActiveRecord
       end
 
       def test_custom_primary_key_in_create_table
-        connection = Barcode.connection
+        connection = Barcode.lease_connection
         connection.create_table :barcodes, id: false, force: true do |t|
           t.primary_key :id, :string
         end
@@ -572,7 +831,7 @@ module ActiveRecord
       end
 
       def test_custom_primary_key_in_change_table
-        connection = Barcode.connection
+        connection = Barcode.lease_connection
         connection.create_table :barcodes, id: false, force: true do |t|
           t.integer :dummy
         end
@@ -591,7 +850,7 @@ module ActiveRecord
       end
 
       def test_add_column_with_custom_primary_key
-        connection = Barcode.connection
+        connection = Barcode.lease_connection
         connection.create_table :barcodes, id: false, force: true do |t|
           t.integer :dummy
         end
@@ -608,7 +867,7 @@ module ActiveRecord
       end
 
       def test_remove_column_preserves_index_options
-        connection = Barcode.connection
+        connection = Barcode.lease_connection
         connection.create_table :barcodes, force: true do |t|
           t.string :code
           t.string :region
@@ -635,7 +894,7 @@ module ActiveRecord
       end
 
       def test_auto_increment_preserved_on_table_changes
-        connection = Barcode.connection
+        connection = Barcode.lease_connection
         connection.create_table :barcodes, force: true do |t|
           t.string :code
         end
@@ -643,7 +902,7 @@ module ActiveRecord
         pk_column = connection.columns("barcodes").find { |col| col.name == "id" }
         sql = connection.exec_query("SELECT sql FROM sqlite_master WHERE tbl_name='barcodes'").rows.first.first
 
-        assert(pk_column.auto_increment?)
+        assert_predicate(pk_column, :auto_increment?)
         assert(sql.match?("PRIMARY KEY AUTOINCREMENT"))
 
         connection.change_column(:barcodes, :code, :integer)
@@ -651,7 +910,7 @@ module ActiveRecord
         pk_column = connection.columns("barcodes").find { |col| col.name == "id" }
         sql = connection.exec_query("SELECT sql FROM sqlite_master WHERE tbl_name='barcodes'").rows.first.first
 
-        assert(pk_column.auto_increment?)
+        assert_predicate(pk_column, :auto_increment?)
         assert(sql.match?("PRIMARY KEY AUTOINCREMENT"))
       end
 
@@ -676,49 +935,55 @@ module ActiveRecord
         statement = ::SQLite3::Statement.new(db,
                                            "CREATE TABLE statement_test (number integer not null)")
         statement.stub(:step, -> { raise ::SQLite3::BusyException.new("busy") }) do
-          assert_called(statement, :columns, returns: []) do
-            assert_called(statement, :close) do
-              ::SQLite3::Statement.stub(:new, statement) do
-                error = assert_raises ActiveRecord::StatementInvalid do
-                  @conn.exec_query "select * from statement_test"
-                end
-                assert_equal @conn.pool, error.connection_pool
+          assert_called(statement, :close) do
+            ::SQLite3::Statement.stub(:new, statement) do
+              error = assert_raises ActiveRecord::StatementTimeout do
+                @conn.exec_query "select * from statement_test"
               end
+              assert_equal @conn.pool, error.connection_pool
             end
           end
         end
       end
 
       def test_db_is_not_readonly_when_readonly_option_is_false
-        conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3",
-                                       readonly: false
+        conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          readonly: false,
+        )
         conn.connect!
 
         assert_not_predicate conn.raw_connection, :readonly?
       end
 
       def test_db_is_not_readonly_when_readonly_option_is_unspecified
-        conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3"
+        conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+        )
         conn.connect!
 
         assert_not_predicate conn.raw_connection, :readonly?
       end
 
       def test_db_is_readonly_when_readonly_option_is_true
-        conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3",
-                                       readonly: true
+        conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          readonly: true,
+        )
         conn.connect!
 
         assert_predicate conn.raw_connection, :readonly?
       end
 
       def test_writes_are_not_permitted_to_readonly_databases
-        conn = Base.sqlite3_connection database: ":memory:",
-                                       adapter: "sqlite3",
-                                       readonly: true
+        conn = SQLite3Adapter.new(
+          database: ":memory:",
+          adapter: "sqlite3",
+          readonly: true,
+        )
         conn.connect!
 
         exception = assert_raises(ActiveRecord::StatementInvalid) do
@@ -729,7 +994,7 @@ module ActiveRecord
       end
 
       def test_strict_strings_by_default
-        conn = Base.sqlite3_connection(database: ":memory:", adapter: "sqlite3")
+        conn = SQLite3Adapter.new(database: ":memory:", adapter: "sqlite3")
         conn.create_table :testings
 
         assert_nothing_raised do
@@ -737,7 +1002,7 @@ module ActiveRecord
         end
 
         with_strict_strings_by_default do
-          conn = Base.sqlite3_connection(database: ":memory:", adapter: "sqlite3")
+          conn = SQLite3Adapter.new(database: ":memory:", adapter: "sqlite3")
           conn.create_table :testings
 
           error = assert_raises(StandardError) do
@@ -749,7 +1014,7 @@ module ActiveRecord
       end
 
       def test_strict_strings_by_default_and_true_in_database_yml
-        conn = Base.sqlite3_connection(database: ":memory:", adapter: "sqlite3", strict: true)
+        conn = SQLite3Adapter.new(database: ":memory:", adapter: "sqlite3", strict: true)
         conn.create_table :testings
 
         error = assert_raises(StandardError) do
@@ -759,7 +1024,7 @@ module ActiveRecord
         assert_equal conn.pool, error.connection_pool
 
         with_strict_strings_by_default do
-          conn = Base.sqlite3_connection(database: ":memory:", adapter: "sqlite3", strict: true)
+          conn = SQLite3Adapter.new(database: ":memory:", adapter: "sqlite3", strict: true)
           conn.create_table :testings
 
           error = assert_raises(StandardError) do
@@ -771,7 +1036,7 @@ module ActiveRecord
       end
 
       def test_strict_strings_by_default_and_false_in_database_yml
-        conn = Base.sqlite3_connection(database: ":memory:", adapter: "sqlite3", strict: false)
+        conn = SQLite3Adapter.new(database: ":memory:", adapter: "sqlite3", strict: false)
         conn.create_table :testings
 
         assert_nothing_raised do
@@ -779,7 +1044,7 @@ module ActiveRecord
         end
 
         with_strict_strings_by_default do
-          conn = Base.sqlite3_connection(database: ":memory:", adapter: "sqlite3", strict: false)
+          conn = SQLite3Adapter.new(database: ":memory:", adapter: "sqlite3", strict: false)
           conn.create_table :testings
 
           assert_nothing_raised do
@@ -851,9 +1116,19 @@ module ActiveRecord
 
         def with_file_connection(options = {})
           options = options.dup
-          db_config = ActiveRecord::Base.configurations.configurations.find { |config| !config.database.include?(":memory:") }
+          db_config = ActiveRecord::Base.configurations.configs_for(env_name: "arunit2", name: "primary")
           options[:database] ||= db_config.database
-          conn = ActiveRecord::Base.sqlite3_connection(options)
+          conn = SQLite3Adapter.new(options)
+
+          yield(conn)
+        ensure
+          conn.disconnect! if conn
+        end
+
+        def with_memory_connection(options = {})
+          options = options.dup
+          options[:database] = ":memory:"
+          conn = SQLite3Adapter.new(options)
 
           yield(conn)
         ensure
