@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 require "cases/helper"
+require "models/attachment"
 require "models/developer"
 require "models/project"
 require "models/company"
@@ -31,6 +32,9 @@ require "models/tree"
 require "models/node"
 require "models/club"
 require "models/cpk"
+require "models/sharded/blog"
+require "models/sharded/blog_post"
+require "models/sharded/comment"
 
 class BelongsToAssociationsTest < ActiveRecord::TestCase
   fixtures :accounts, :companies, :developers, :projects, :topics,
@@ -400,6 +404,18 @@ class BelongsToAssociationsTest < ActiveRecord::TestCase
     assert_equal 3, book.shop_id
   end
 
+  def test_should_reload_association_on_model_with_query_constraints_when_foreign_key_changes
+    blog = Sharded::Blog.create!
+    blog_post = Sharded::BlogPost.create!(blog: blog)
+    comment = Sharded::Comment.create!(blog: blog)
+
+    # Load the association once
+    comment.blog_post
+    comment.blog_post_id = blog_post.id
+
+    assert_equal blog_post, comment.blog_post
+  end
+
   def test_building_the_belonging_object_with_implicit_sti_base_class
     account = Account.new
     company = account.build_firm
@@ -1434,6 +1450,20 @@ class BelongsToAssociationsTest < ActiveRecord::TestCase
     assert_equal touch_time, car.reload.wheels_owned_at
   end
 
+  def test_polymorphic_stale_state_handles_nil_foreign_keys_correctly
+    klass = Class.new(ActiveRecord::Base) do
+      self.table_name = "records"
+
+      has_one :attachment, as: :record
+
+      def self.polymorphic_name
+        "Blob"
+      end
+    end
+
+    assert_nothing_raised { Attachment.create!(record: klass.build, record_type: "Document") }
+  end
+
   def test_build_with_conditions
     client = companies(:second_client)
     firm   = client.build_bob_firm
