@@ -1,13 +1,13 @@
 # frozen_string_literal: true
 
 require "cases/helper"
-require "models/comment"
 require "models/post"
 require "models/subscriber"
+require "models/developer"
 require "models/cpk"
 
 class EachTest < ActiveRecord::TestCase
-  fixtures :posts, :subscribers, :cpk_orders
+  fixtures :posts, :subscribers, :developers, :cpk_orders
 
   def setup
     @posts = Post.order("id asc")
@@ -16,7 +16,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_each_should_execute_one_query_per_batch
-    assert_queries(@total + 1) do
+    assert_queries_count(@total + 1) do
       Post.find_each(batch_size: 1) do |post|
         assert_kind_of Post, post
       end
@@ -24,14 +24,14 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_each_should_not_return_query_chain_and_execute_only_one_query
-    assert_queries(1) do
+    assert_queries_count(1) do
       result = Post.find_each(batch_size: 100000) { }
       assert_nil result
     end
   end
 
   def test_each_should_return_an_enumerator_if_no_block_is_present
-    assert_queries(1) do
+    assert_queries_count(1) do
       Post.find_each(batch_size: 100000).with_index do |post, index|
         assert_kind_of Post, post
         assert_kind_of Integer, index
@@ -46,7 +46,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_each_enumerator_should_execute_one_query_per_batch
-    assert_queries(@total + 1) do
+    assert_queries_count(@total + 1) do
       Post.find_each(batch_size: 1).with_index do |post, index|
         assert_kind_of Post, post
         assert_kind_of Integer, index
@@ -63,7 +63,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_each_should_execute_if_id_is_in_select
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.select("id, title, type").find_each(batch_size: 2) do |post|
         assert_kind_of Post, post
       end
@@ -114,7 +114,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_find_in_batches_should_return_batches
-    assert_queries(@total + 1) do
+    assert_queries_count(@total + 1) do
       Post.find_in_batches(batch_size: 1) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Post, batch.first
@@ -123,7 +123,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_find_in_batches_should_start_from_the_start_option
-    assert_queries(@total) do
+    assert_queries_count(@total) do
       Post.find_in_batches(batch_size: 1, start: 2) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Post, batch.first
@@ -132,7 +132,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_find_in_batches_should_end_at_the_finish_option
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.find_in_batches(batch_size: 1, finish: 5) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Post, batch.first
@@ -141,18 +141,17 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_find_in_batches_shouldnt_execute_query_unless_needed
-    assert_queries(2) do
+    assert_queries_count(2) do
       Post.find_in_batches(batch_size: @total) { |batch| assert_kind_of Array, batch }
     end
 
-    assert_queries(1) do
+    assert_queries_count(1) do
       Post.find_in_batches(batch_size: @total + 1) { |batch| assert_kind_of Array, batch }
     end
   end
 
   def test_find_in_batches_should_quote_batch_order
-    c = Post.connection
-    assert_sql(/ORDER BY #{Regexp.escape(c.quote_table_name("posts.id"))}/i) do
+    assert_queries_match(/ORDER BY #{Regexp.escape(quote_table_name("posts.id"))}/i) do
       Post.find_in_batches(batch_size: 1) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Post, batch.first
@@ -161,8 +160,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_find_in_batches_should_quote_batch_order_with_desc_order
-    c = Post.connection
-    assert_sql(/ORDER BY #{Regexp.escape(c.quote_table_name("posts.id"))} DESC/) do
+    assert_queries_match(/ORDER BY #{Regexp.escape(quote_table_name("posts.id"))} DESC/) do
       Post.find_in_batches(batch_size: 1, order: :desc) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Post, batch.first
@@ -269,7 +267,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_find_in_batches_should_use_any_column_as_primary_key_when_start_is_not_specified
-    assert_queries(Subscriber.count + 1) do
+    assert_queries_count(Subscriber.count + 1) do
       Subscriber.find_in_batches(batch_size: 1) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Subscriber, batch.first
@@ -282,7 +280,7 @@ class EachTest < ActiveRecord::TestCase
     assert_no_queries do
       enum = Post.find_in_batches(batch_size: 1)
     end
-    assert_queries(4) do
+    assert_queries_count(4) do
       enum.first(4) do |batch|
         assert_kind_of Array, batch
         assert_kind_of Post, batch.first
@@ -318,6 +316,16 @@ class EachTest < ActiveRecord::TestCase
     end
   end
 
+  def test_in_batches_should_error_on_ignore_the_order
+    assert_raise(ArgumentError, match: "Scoped order is ignored") do
+      PostWithDefaultScope.in_batches(error_on_ignore: true) { }
+    end
+
+    assert_raise(ArgumentError, match: "Scoped order is ignored") do
+      PostWithDefaultScope.in_batches(error_on_ignore: true).delete_all
+    end
+  end
+
   def test_in_batches_has_attribute_readers
     enumerator = Post.no_comments.in_batches(of: 2, start: 42, finish: 84)
     assert_equal Post.no_comments, enumerator.relation
@@ -327,7 +335,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_should_yield_relation_if_block_given
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.in_batches(of: 2) do |relation|
         assert_kind_of ActiveRecord::Relation, relation
       end
@@ -335,7 +343,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_should_be_enumerable_if_no_block_given
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.in_batches(of: 2).each do |relation|
         assert_kind_of ActiveRecord::Relation, relation
       end
@@ -343,7 +351,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_each_record_should_yield_record_if_block_is_given
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.in_batches(of: 2).each_record do |post|
         assert_predicate post.title, :present?
         assert_kind_of Post, post
@@ -352,7 +360,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_each_record_should_return_enumerator_if_no_block_given
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.in_batches(of: 2).each_record.with_index do |post, i|
         assert_predicate post.title, :present?
         assert_kind_of Post, post
@@ -362,7 +370,7 @@ class EachTest < ActiveRecord::TestCase
 
   def test_in_batches_each_record_should_be_ordered_by_id
     ids = Post.order("id ASC").pluck(:id)
-    assert_queries(6) do
+    assert_queries_count(6) do
       Post.in_batches(of: 2).each_record.with_index do |post, i|
         assert_equal ids[i], post.id
       end
@@ -370,7 +378,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_update_all_affect_all_records
-    assert_queries(6 + 6) do # 6 selects, 6 updates
+    assert_queries_count(6 + 6) do # 6 selects, 6 updates
       Post.in_batches(of: 2).update_all(title: "updated-title")
     end
     assert_equal Post.all.pluck(:title), ["updated-title"] * Post.count
@@ -384,6 +392,22 @@ class EachTest < ActiveRecord::TestCase
     assert_equal 0, Post.where("1=0").in_batches(of: 2).update_all(title: "updated-title")
   end
 
+  def test_in_batches_touch_all_affect_all_records
+    time = Time.new(2000, 1, 1, 0, 0, 0)
+    assert_queries_count(6 + 6) do # 6 selects, 6 updates
+      Developer.in_batches(of: 2).touch_all(time: time)
+    end
+    assert_equal [time] * Developer.count, Developer.all.pluck(:updated_at)
+  end
+
+  def test_in_batches_touch_all_returns_rows_affected
+    assert_equal 11, Developer.in_batches(of: 2).touch_all
+  end
+
+  def test_in_batches_touch_all_returns_zero_when_no_batches
+    assert_equal 0, Developer.where("1=0").in_batches(of: 2).touch_all
+  end
+
   def test_in_batches_delete_all_should_not_delete_records_in_other_batches
     not_deleted_count = Post.where("id <= 2").count
     Post.where("id > 2").in_batches(of: 2).delete_all
@@ -399,6 +423,22 @@ class EachTest < ActiveRecord::TestCase
     assert_equal 0, Post.where("1=0").in_batches(of: 2).delete_all
   end
 
+  def test_in_batches_destroy_all_should_not_destroy_records_in_other_batches
+    not_destroyed_count = Post.where("id <= 2").count
+    Post.where("id > 2").in_batches(of: 2).destroy_all
+    assert_equal 0, Post.where("id > 2").count
+    assert_equal not_destroyed_count, Post.count
+  end
+
+  def test_in_batches_destroy_all_returns_rows_affected
+    # 1 records is not destroyed because of the callback.
+    assert_equal 10, PostWithDestroyCallback.in_batches(of: 2).destroy_all
+  end
+
+  def test_in_batches_destroy_all_returns_zero_when_no_batches
+    assert_equal 0, Post.where("1=0").in_batches(of: 2).destroy_all
+  end
+
   def test_in_batches_should_not_be_loaded
     Post.in_batches(of: 1) do |relation|
       assert_not_predicate relation, :loaded?
@@ -416,7 +456,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_if_not_loaded_executes_more_queries
-    assert_queries(@total + 1) do
+    assert_queries_count(@total + 1) do
       Post.in_batches(of: 1, load: false) do |relation|
         assert_not_predicate relation, :loaded?
       end
@@ -428,7 +468,7 @@ class EachTest < ActiveRecord::TestCase
     posts.load
     batch_count = 0
     last_id = posts.map(&:id).min
-    assert_queries(0) do
+    assert_queries_count(0) do
       posts.in_batches(of: 1) do |relation|
         batch_count += 1
         assert_kind_of ActiveRecord::Relation, relation
@@ -445,7 +485,7 @@ class EachTest < ActiveRecord::TestCase
     posts.load
     batch_count = 0
     last_id = posts.map(&:id).max
-    assert_queries(0) do
+    assert_queries_count(0) do
       posts.in_batches(of: 1, order: :desc) do |relation|
         batch_count += 1
         assert_kind_of ActiveRecord::Relation, relation
@@ -464,7 +504,7 @@ class EachTest < ActiveRecord::TestCase
 
     start_id = posts.map(&:id)[1]
     finish_id = posts.map(&:id)[-2]
-    assert_queries(0) do
+    assert_queries_count(0) do
       posts.in_batches(of: 1, start: start_id, finish: finish_id) do |relation|
         batch_count += 1
         assert_kind_of ActiveRecord::Relation, relation
@@ -474,12 +514,29 @@ class EachTest < ActiveRecord::TestCase
     assert_equal posts.size - 2, batch_count
   end
 
+  def test_in_batches_when_loaded_runs_no_queries_with_start_and_end_arguments_and_reverse_order
+    posts = Post.all.order(id: :asc)
+    posts.load
+    batch_count = 0
+
+    start_id = posts.map(&:id)[-2]
+    finish_id = posts.map(&:id)[1]
+    assert_queries_count(0) do
+      posts.in_batches(of: 1, start: start_id, finish: finish_id, order: :desc) do |relation|
+        batch_count += 1
+        assert_kind_of ActiveRecord::Relation, relation
+      end
+    end
+
+    assert_equal posts.size - 2, batch_count
+  end
+
   def test_in_batches_when_loaded_can_return_an_enum
     posts = Post.all
     posts.load
     batch_count = 0
 
-    assert_queries(0) do
+    assert_queries_count(0) do
       posts.in_batches(of: 1).each do |relation|
         batch_count += 1
         assert_kind_of ActiveRecord::Relation, relation
@@ -489,8 +546,48 @@ class EachTest < ActiveRecord::TestCase
     assert_equal posts.size, batch_count
   end
 
+  def test_in_batches_when_loaded_runs_no_queries_when_batching_over_cpk_model
+    incorrectly_sorted_orders = Cpk::Order.order(shop_id: :asc, id: :desc)
+    incorrectly_sorted_orders.load
+
+    correctly_sorted_orders = Cpk::Order.order(shop_id: :desc, id: :asc).to_a
+    expected_orders = correctly_sorted_orders[1..-2]
+    start_id = expected_orders.first.id
+    finish_id = expected_orders.last.id
+    orders = []
+
+    assert_no_queries do
+      incorrectly_sorted_orders.find_each(batch_size: 1, start: start_id, finish: finish_id, order: [:desc, :asc]) do |order|
+        orders << order
+      end
+    end
+
+    assert_equal expected_orders, orders
+  end
+
+  def test_in_batches_when_loaded_iterates_using_custom_column
+    c = Post.lease_connection
+    c.add_index(:posts, :title, unique: true)
+    ActiveRecord::Base.schema_cache.clear!
+
+    ordered_posts = Post.order(id: :desc)
+    ordered_posts.load
+
+    posts = []
+
+    assert_no_queries do
+      ordered_posts.in_batches(of: 1, cursor: :id, order: :desc).each_record do |post|
+        posts << post
+      end
+    end
+
+    assert_equal ordered_posts.to_a, posts
+  ensure
+    c.remove_index(:posts, :title)
+  end
+
   def test_in_batches_should_return_relations
-    assert_queries(@total + 1) do
+    assert_queries_count(@total + 1) do
       Post.in_batches(of: 1) do |relation|
         assert_kind_of ActiveRecord::Relation, relation
       end
@@ -499,7 +596,7 @@ class EachTest < ActiveRecord::TestCase
 
   def test_in_batches_should_start_from_the_start_option
     post = Post.order("id ASC").where("id >= ?", 2).first
-    assert_queries(2) do
+    assert_queries_count(2) do
       relation = Post.in_batches(of: 1, start: 2).first
       assert_equal post, relation.first
     end
@@ -507,65 +604,59 @@ class EachTest < ActiveRecord::TestCase
 
   def test_in_batches_should_end_at_the_finish_option
     post = Post.order("id DESC").where("id <= ?", 5).first
-    assert_queries(7) do
+    assert_queries_count(7) do
       relation = Post.in_batches(of: 1, finish: 5, load: true).reverse_each.first
       assert_equal post, relation.last
     end
   end
 
   def test_in_batches_executes_range_queries_when_unconstrained
-    c = Post.connection
-    quoted_posts_id = Regexp.escape(c.quote_table_name("posts.id"))
-    assert_sql(/WHERE #{quoted_posts_id} > .+ AND #{quoted_posts_id} <= .+/i) do
+    quoted_posts_id = Regexp.escape(quote_table_name("posts.id"))
+    assert_queries_match(/WHERE #{quoted_posts_id} > .+ AND #{quoted_posts_id} <= .+/i) do
       Post.in_batches(of: 2) { |relation| assert_kind_of Post, relation.first }
     end
   end
 
   def test_in_batches_executes_in_queries_when_unconstrained_and_opted_out_of_ranges
-    c = Post.connection
-    quoted_posts_id = Regexp.escape(c.quote_table_name("posts.id"))
-    assert_sql(/#{quoted_posts_id} IN \(.+\)/i) do
+    quoted_posts_id = Regexp.escape(quote_table_name("posts.id"))
+    assert_queries_match(/#{quoted_posts_id} IN \(.+\)/i) do
       Post.in_batches(of: 2, use_ranges: false) { |relation| assert_kind_of Post, relation.first }
     end
   end
 
   def test_in_batches_executes_in_queries_when_constrained
-    c = Post.connection
-    quoted_posts_id = Regexp.escape(c.quote_table_name("posts.id"))
-    assert_sql(/#{quoted_posts_id} IN \(.+\)/i) do
+    quoted_posts_id = Regexp.escape(quote_table_name("posts.id"))
+    assert_queries_match(/#{quoted_posts_id} IN \(.+\)/i) do
       Post.where("id < ?", 5).in_batches(of: 2) { |relation| assert_kind_of Post, relation.first }
     end
   end
 
   def test_in_batches_executes_range_queries_when_constrained_and_opted_in_into_ranges
-    c = Post.connection
-    quoted_posts_id = Regexp.escape(c.quote_table_name("posts.id"))
-    assert_sql(/#{quoted_posts_id} > .+ AND #{quoted_posts_id} <= .+/i) do
+    quoted_posts_id = Regexp.escape(quote_table_name("posts.id"))
+    assert_queries_match(/#{quoted_posts_id} > .+ AND #{quoted_posts_id} <= .+/i) do
       Post.where("id < ?", 5).in_batches(of: 2, use_ranges: true) { |relation| assert_kind_of Post, relation.first }
     end
   end
 
   def test_in_batches_no_subqueries_for_whole_tables_batching
-    c = Post.connection
-    quoted_posts_id = Regexp.escape(c.quote_table_name("posts.id"))
-    assert_sql(/DELETE FROM #{Regexp.escape(c.quote_table_name("posts"))} WHERE #{quoted_posts_id} > .+ AND #{quoted_posts_id} <=/i) do
+    quoted_posts_id = Regexp.escape(quote_table_name("posts.id"))
+    assert_queries_match(/DELETE FROM #{Regexp.escape(quote_table_name("posts"))} WHERE #{quoted_posts_id} > .+ AND #{quoted_posts_id} <=/i) do
       Post.in_batches(of: 2).delete_all
     end
   end
 
   def test_in_batches_shouldnt_execute_query_unless_needed
-    assert_queries(2) do
+    assert_queries_count(2) do
       Post.in_batches(of: @total) { |relation| assert_kind_of ActiveRecord::Relation, relation }
     end
 
-    assert_queries(1) do
+    assert_queries_count(1) do
       Post.in_batches(of: @total + 1) { |relation| assert_kind_of ActiveRecord::Relation, relation }
     end
   end
 
   def test_in_batches_should_quote_batch_order
-    c = Post.connection
-    assert_sql(/ORDER BY #{Regexp.escape(c.quote_table_name('posts'))}\.#{Regexp.escape(c.quote_column_name('id'))}/) do
+    assert_queries_match(/ORDER BY #{Regexp.escape(quote_table_name("posts.id"))}/) do
       Post.in_batches(of: 1) do |relation|
         assert_kind_of ActiveRecord::Relation, relation
         assert_kind_of Post, relation.first
@@ -574,8 +665,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_should_quote_batch_order_with_desc_order
-    c = Post.connection
-    assert_sql(/ORDER BY #{Regexp.escape(c.quote_table_name("posts.id"))} DESC/) do
+    assert_queries_match(/ORDER BY #{Regexp.escape(quote_table_name("posts.id"))} DESC/) do
       Post.in_batches(of: 1, order: :desc) do |relation|
         assert_kind_of ActiveRecord::Relation, relation
         assert_kind_of Post, relation.first
@@ -584,8 +674,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_enumerator_should_quote_batch_order_with_desc_order
-    c = Post.connection
-    assert_sql(/ORDER BY #{Regexp.escape(c.quote_table_name("posts.id"))} DESC/) do
+    assert_queries_match(/ORDER BY #{Regexp.escape(quote_table_name("posts.id"))} DESC/) do
       relation = Post.in_batches(of: 1, order: :desc).first
       assert_kind_of ActiveRecord::Relation, relation
       assert_kind_of Post, relation.first
@@ -593,8 +682,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_enumerator_each_record_should_quote_batch_order_with_desc_order
-    c = Post.connection
-    assert_sql(/ORDER BY #{Regexp.escape(c.quote_table_name("posts.id"))} DESC/) do
+    assert_queries_match(/ORDER BY #{Regexp.escape(quote_table_name("posts.id"))} DESC/) do
       Post.in_batches(of: 1, order: :desc).each_record do |record|
         assert_kind_of Post, record
       end
@@ -639,7 +727,7 @@ class EachTest < ActiveRecord::TestCase
   end
 
   def test_in_batches_should_use_any_column_as_primary_key_when_start_is_not_specified
-    assert_queries(Subscriber.count + 1) do
+    assert_queries_count(Subscriber.count + 1) do
       Subscriber.in_batches(of: 1, load: true) do |relation|
         assert_kind_of ActiveRecord::Relation, relation
         assert_kind_of Subscriber, relation.first
@@ -652,7 +740,7 @@ class EachTest < ActiveRecord::TestCase
     assert_no_queries do
       enum = Post.in_batches(of: 1)
     end
-    assert_queries(4) do
+    assert_queries_count(4) do
       enum.first(4) do |relation|
         assert_kind_of ActiveRecord::Relation, relation
         assert_kind_of Post, relation.first
@@ -692,6 +780,79 @@ class EachTest < ActiveRecord::TestCase
     assert_equal 2, person.reload.author_id # incremented only once
   end
 
+  def test_in_batches_with_custom_columns_raises_when_start_missing_items
+    assert_raises(ArgumentError, match: ":start must contain one value per cursor column") do
+      Post.in_batches(start: 1, cursor: [:author_id, :id]) { }
+    end
+  end
+
+  def test_in_batches_with_custom_columns_raises_when_finish_missing_items
+    assert_raises(ArgumentError, match: ":finish must contain one value per cursor column") do
+      Post.in_batches(finish: 10, cursor: [:author_id, :id]) { }
+    end
+  end
+
+  def test_in_batches_with_custom_columns_raises_when_non_unique_columns
+    ActiveRecord::Base.schema_cache.clear!
+
+    # Non unique column.
+    assert_raises(ArgumentError, match: /must include a primary key/) do
+      Post.in_batches(cursor: :title) { }
+    end
+
+    # Primary key column.
+    assert_nothing_raised do
+      Post.in_batches(cursor: :id) { }
+    end
+
+    c = Post.lease_connection
+    c.add_index(:posts, :title)
+    ActiveRecord::Base.schema_cache.clear!
+
+    # Non unique indexed column.
+    assert_raises(ArgumentError, match: /must include a primary key/) do
+      Post.in_batches(cursor: :title) { }
+    end
+
+    c.remove_index(:posts, :title)
+
+    if current_adapter?(:PostgreSQLAdapter)
+      c.add_index(:posts, :title, unique: true, where: "id > 5")
+      ActiveRecord::Base.schema_cache.clear!
+
+      # Column having a unique, but partial, index.
+      assert_raises(ArgumentError, match: /must include a primary key/) do
+        Post.in_batches(cursor: :title) { }
+      end
+
+      c.remove_index(:posts, :title)
+    end
+
+    c.add_index(:posts, :title, unique: true)
+    ActiveRecord::Base.schema_cache.clear!
+    assert_nothing_raised do
+      Post.in_batches(cursor: :title) { }
+    end
+  ensure
+    c.remove_index(:posts, :title)
+  end
+
+  def test_in_batches_iterating_using_custom_columns
+    c = Post.lease_connection
+    c.add_index(:posts, :title, unique: true)
+    ActiveRecord::Base.schema_cache.clear!
+
+    expected_posts = Post.order(id: :desc).to_a
+    posts = []
+    Post.in_batches(of: 1, cursor: :id, order: :desc).each_record do |post|
+      posts << post
+    end
+
+    assert_equal expected_posts, posts
+  ensure
+    c.remove_index(:posts, :title)
+  end
+
   def test_find_in_batches_should_return_a_sized_enumerator
     assert_equal 11, Post.find_in_batches(batch_size: 1).size
     assert_equal 6, Post.find_in_batches(batch_size: 2).size
@@ -763,23 +924,17 @@ class EachTest < ActiveRecord::TestCase
   end
 
   test ".find_each respects table alias" do
-    assert_queries(1) do
+    assert_queries_count(1) do
       table_alias = Post.arel_table.alias("omg_posts")
-      table_metadata = ActiveRecord::TableMetadata.new(Post, table_alias)
-      predicate_builder = ActiveRecord::PredicateBuilder.new(table_metadata)
 
-      posts = ActiveRecord::Relation.create(
-        Post,
-        table: table_alias,
-        predicate_builder: predicate_builder
-      )
+      posts = ActiveRecord::Relation.create(Post, table: table_alias)
       posts.find_each { }
     end
   end
 
   test ".find_each bypasses the query cache for its own queries" do
     Post.cache do
-      assert_queries(2) do
+      assert_queries_count(2) do
         Post.find_each { }
         Post.find_each { }
       end
@@ -789,7 +944,7 @@ class EachTest < ActiveRecord::TestCase
   test ".find_each does not disable the query cache inside the given block" do
     Post.cache do
       Post.find_each(start: 1, finish: 1) do |post|
-        assert_queries(1) do
+        assert_queries_count(1) do
           post.comments.count
           post.comments.count
         end
@@ -799,7 +954,7 @@ class EachTest < ActiveRecord::TestCase
 
   test ".find_in_batches bypasses the query cache for its own queries" do
     Post.cache do
-      assert_queries(2) do
+      assert_queries_count(2) do
         Post.find_in_batches { }
         Post.find_in_batches { }
       end
@@ -809,7 +964,7 @@ class EachTest < ActiveRecord::TestCase
   test ".find_in_batches does not disable the query cache inside the given block" do
     Post.cache do
       Post.find_in_batches(start: 1, finish: 1) do |batch|
-        assert_queries(1) do
+        assert_queries_count(1) do
           batch.first.comments.count
           batch.first.comments.count
         end
@@ -819,7 +974,7 @@ class EachTest < ActiveRecord::TestCase
 
   test ".in_batches bypasses the query cache for its own queries" do
     Post.cache do
-      assert_queries(2) do
+      assert_queries_count(2) do
         Post.in_batches { }
         Post.in_batches { }
       end
@@ -829,7 +984,7 @@ class EachTest < ActiveRecord::TestCase
   test ".in_batches does not disable the query cache inside the given block" do
     Post.cache do
       Post.in_batches(start: 1, finish: 1) do |relation|
-        assert_queries(1) do
+        assert_queries_count(1) do
           relation.count
           relation.count
         end
