@@ -267,7 +267,7 @@ if ActiveRecord::Base.lease_connection.prepared_statements
           cache = klass.send(:cached_find_by_statement, @connection, key) do
             raise "#{klass} has no cached statement by #{key.inspect}"
           end
-          cache.send(:query_builder).instance_variable_get(:@sql)
+          cache.instance_variable_get(:@query_builder).instance_variable_get(:@sql)
         end
 
         def statement_cache
