@@ -203,58 +203,6 @@ module ActiveRecord
           ENV["RAILS_ENV"] = previous_env
         end
 
-        def test_shard_swapping_prohibition_exception_recovery
-          previous_env, ENV["RAILS_ENV"] = ENV["RAILS_ENV"], "default_env"
-
-          config = {
-            "default_env" => {
-              "primary" => { "adapter" => "sqlite3", "database" => "test/db/primary.sqlite3" },
-              "primary_shard_one" => { "adapter" => "sqlite3", "database" => "test/db/primary_shard_one.sqlite3" },
-              "primary_shard_two" => { "adapter" => "sqlite3", "database" => "test/db/primary_shard_two.sqlite3" },
-            }
-          }
-
-          @prev_configs, ActiveRecord::Base.configurations = ActiveRecord::Base.configurations, config
-
-          PrimaryBase.connects_to(shards: {
-            default: { writing: :primary },
-            shard_one: { writing: :primary_shard_one }
-          })
-
-          global_role = :writing
-
-          # Switch everything to default
-          ActiveRecord::Base.connected_to(role: global_role, shard: :default) do
-            assert_equal "primary", PrimaryBase.connection_pool.db_config.name
-
-            # Switch only primary to shard_one
-            PrimaryBase.connected_to(shard: :shard_one) do
-              assert_equal "primary_shard_one", PrimaryBase.connection_pool.db_config.name
-
-              PrimaryBase.prohibit_shard_swapping do
-                e = assert_raises(ArgumentError) do
-                  PrimaryBase.connected_to(shard: :shard_two) { }
-                end
-                assert_match(/cannot swap/, e.message)
-              end
-
-              assert_equal "primary_shard_one", PrimaryBase.connection_pool.db_config.name
-
-              PrimaryBase.prohibit_shard_swapping do
-                e = assert_raises(ArgumentError) do
-                  ActiveRecord::Base.connected_to_many([PrimaryBase], shard: :shard_two, role: :writing) { }
-                end
-                assert_match(/cannot swap/, e.message)
-              end
-
-              assert_equal "primary_shard_one", PrimaryBase.connection_pool.db_config.name
-            end
-          end
-        ensure
-          ActiveRecord::Base.configurations = @prev_configs
-          ActiveRecord::Base.establish_connection(:arunit)
-          ENV["RAILS_ENV"] = previous_env
-        end
         def test_roles_and_shards_can_be_swapped_granularly
           previous_env, ENV["RAILS_ENV"] = ENV["RAILS_ENV"], "default_env"
 
@@ -512,6 +460,34 @@ module ActiveRecord
           Object.send(:remove_const, :ApplicationRecord)
           ActiveRecord::Base.establish_connection :arunit
         end
+
+        def test_prevent_writes_handles_class_reloading
+          # Regression test for https://github.com/rails/rails/issues/54343
+          Object.const_set(:ReloadedRecord, Class.new(ActiveRecord::Base) { self.abstract_class = true })
+          ReloadedRecord.connects_to(database: { writing: :arunit, reading: :arunit })
+
+          ActiveRecord::Base.connected_to(role: :reading, prevent_writes: true) do
+            ReloadedRecord.connected_to(role: :writing, prevent_writes: false) do
+              assert_not_predicate ReloadedRecord.lease_connection, :preventing_writes?
+            end
+          end
+
+          # emulate a reload in development mode
+          Object.send(:remove_const, :ReloadedRecord)
+          Object.const_set(:ReloadedRecord, Class.new(ActiveRecord::Base) { self.abstract_class = true })
+          ReloadedRecord.connects_to(database: { writing: :arunit, reading: :arunit })
+
+          ActiveRecord::Base.connected_to(role: :reading, prevent_writes: true) do
+            ReloadedRecord.connected_to(role: :writing, prevent_writes: false) do
+              assert_not_predicate ReloadedRecord.lease_connection, :preventing_writes?
+            end
+          end
+        ensure
+          ReloadedRecord.remove_connection
+          ActiveRecord.application_record_class = nil
+          Object.send(:remove_const, :ReloadedRecord)
+          ActiveRecord::Base.establish_connection :arunit
+        end
       end
     end
   end
