@@ -146,6 +146,13 @@ class TokenForTest < ActiveRecord::TestCase
     assert_nil custom_pk.find_by_token_for(:lookup, @lookup_token)
   end
 
+  test "finds record with a composite primary key" do
+    book = Cpk::Book.create!(id: [1, 3], shop_id: 2)
+    token = book.generate_token_for(:test)
+
+    assert_equal book, Cpk::Book.find_by_token_for(:test, token)
+  end
+
   test "raises when no primary key has been declared" do
     no_pk = Class.new(Matey) do
       generates_token_for :parley
