@@ -10,7 +10,7 @@ require_relative "../behaviors"
 class SlowRedis < Redis
   def get(key)
     if /latency/.match?(key)
-      sleep 3
+      sleep 0.2
       super
     else
       super
@@ -123,7 +123,9 @@ module ActiveSupport::Cache::RedisCacheStoreTests
     end
 
     test "instantiating the store doesn't connect to Redis" do
-      build(url: "redis://localhost:1")
+      assert_nothing_raised do
+        build(url: "redis://localhost:1")
+      end
     end
 
     private
@@ -135,7 +137,7 @@ module ActiveSupport::Cache::RedisCacheStoreTests
   class StoreTest < ActiveSupport::TestCase
     setup do
       @cache = nil
-      skip "redis server is not up" unless REDIS_UP
+      skip "Redis server is not up" unless REDIS_UP
       @namespace = "test-#{SecureRandom.hex}"
 
       @cache = lookup_store(expires_in: 60)
@@ -195,6 +197,11 @@ module ActiveSupport::Cache::RedisCacheStoreTests
       end
     end
 
+    def test_write_with_unless_exist
+      assert_equal true, @cache.write("foo", 1)
+      assert_equal false, @cache.write("foo", 1, unless_exist: true)
+    end
+
     def test_increment_ttl
       # existing key
       redis_backend(@cache_no_ttl) { |r| r.set "#{@namespace}:jar", 10 }
@@ -213,7 +220,7 @@ module ActiveSupport::Cache::RedisCacheStoreTests
     end
 
     def test_increment_expires_in
-      @cache.increment "foo", 1, expires_in: 60
+      @cache.increment "foo", expires_in: 60
       redis_backend do |r|
         assert r.exists?("#{@namespace}:foo")
         assert r.ttl("#{@namespace}:foo") > 0
@@ -221,14 +228,14 @@ module ActiveSupport::Cache::RedisCacheStoreTests
 
       # key and ttl exist
       redis_backend { |r| r.setex "#{@namespace}:bar", 120, 1 }
-      @cache.increment "bar", 1, expires_in: 60
+      @cache.increment "bar", expires_in: 60
       redis_backend do |r|
         assert r.ttl("#{@namespace}:bar") > 60
       end
 
       # key exist but not have expire
       redis_backend(@cache_no_ttl) { |r| r.set "#{@namespace}:dar", 10 }
-      @cache_no_ttl.increment "dar", 1, expires_in: 60
+      @cache_no_ttl.increment "dar", expires_in: 60
       redis_backend(@cache_no_ttl) do |r|
         assert r.ttl("#{@namespace}:dar") > 0
       end
@@ -305,14 +312,12 @@ module ActiveSupport::Cache::RedisCacheStoreTests
   class ConnectionPoolBehaviorTest < StoreTest
     include ConnectionPoolBehavior
 
-    def test_deprecated_connection_pool_works
-      assert_deprecated(ActiveSupport.deprecator) do
-        cache = ActiveSupport::Cache.lookup_store(:redis_cache_store, pool_size: 2, pool_timeout: 1)
-        pool = cache.redis # loads 'connection_pool' gem
-        assert_kind_of ::ConnectionPool, pool
-        assert_equal 2, pool.size
-        assert_equal 1, pool.instance_variable_get(:@timeout)
-      end
+    def test_pool_options_work
+      cache = ActiveSupport::Cache.lookup_store(:redis_cache_store, pool: { size: 2, timeout: 1 })
+      pool = cache.redis # loads 'connection_pool' gem
+      assert_kind_of ::ConnectionPool, pool
+      assert_equal 2, pool.size
+      assert_equal 1, pool.instance_variable_get(:@timeout)
     end
 
     def test_connection_pooling_by_default
