@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "active_support/testing/strict_warnings"
+require_relative "../../tools/strict_warnings"
 
 ENV["RAILS_ENV"] ||= "test"
 
@@ -16,18 +16,12 @@ require "rails/all"
 
 module TestApp
   class Application < Rails::Application
-    config.root = __dir__
+    config.root = File.expand_path("../../", __FILE__)
   end
 end
 
 class ActiveSupport::TestCase
   include ActiveSupport::Testing::Stream
-
-  private
-    # Skips the current run on JRuby using Minitest::Assertions#skip
-    def jruby_skip(message = "")
-      skip message if defined?(JRUBY_VERSION)
-    end
 end
 
 require_relative "../../tools/test_common"
