@@ -7,19 +7,71 @@ require "generators/shared_generator_tests"
 require "rails/engine/updater"
 
 DEFAULT_PLUGIN_FILES = %w(
+  .git
+  .github/dependabot.yml
+  .github/workflows/ci.yml
   .gitignore
+  .rubocop.yml
   Gemfile
-  Rakefile
-  README.md
-  bukkits.gemspec
   MIT-LICENSE
-  lib
+  README.md
+  Rakefile
+  bin/rubocop
+  bin/test
+  bukkits.gemspec
   lib/bukkits.rb
-  lib/tasks/bukkits_tasks.rake
+  lib/bukkits/railtie.rb
   lib/bukkits/version.rb
+  lib/tasks/bukkits_tasks.rake
   test/bukkits_test.rb
+  test/dummy/Rakefile
+  test/dummy/app/assets/images/.keep
+  test/dummy/app/assets/stylesheets/application.css
+  test/dummy/app/controllers/application_controller.rb
+  test/dummy/app/controllers/concerns/.keep
+  test/dummy/app/helpers/application_helper.rb
+  test/dummy/app/jobs/application_job.rb
+  test/dummy/app/mailers/application_mailer.rb
+  test/dummy/app/models/application_record.rb
+  test/dummy/app/models/concerns/.keep
+  test/dummy/app/views/layouts/application.html.erb
+  test/dummy/app/views/layouts/mailer.html.erb
+  test/dummy/app/views/layouts/mailer.text.erb
+  test/dummy/app/views/pwa/manifest.json.erb
+  test/dummy/app/views/pwa/service-worker.js
+  test/dummy/bin/dev
+  test/dummy/bin/rails
+  test/dummy/bin/rake
+  test/dummy/bin/setup
+  test/dummy/config.ru
+  test/dummy/config/application.rb
+  test/dummy/config/boot.rb
+  test/dummy/config/cable.yml
+  test/dummy/config/database.yml
+  test/dummy/config/environment.rb
+  test/dummy/config/environments/development.rb
+  test/dummy/config/environments/production.rb
+  test/dummy/config/environments/test.rb
+  test/dummy/config/initializers/content_security_policy.rb
+  test/dummy/config/initializers/filter_parameter_logging.rb
+  test/dummy/config/initializers/inflections.rb
+  test/dummy/config/locales/en.yml
+  test/dummy/config/puma.rb
+  test/dummy/config/routes.rb
+  test/dummy/config/storage.yml
+  test/dummy/log/.keep
+  test/dummy/public/400.html
+  test/dummy/public/404.html
+  test/dummy/public/406-unsupported-browser.html
+  test/dummy/public/422.html
+  test/dummy/public/500.html
+  test/dummy/public/icon.png
+  test/dummy/public/icon.svg
+  test/dummy/storage/.keep
+  test/dummy/tmp/.keep
+  test/dummy/tmp/pids/.keep
+  test/dummy/tmp/storage/.keep
   test/test_helper.rb
-  test/dummy
 )
 
 class PluginGeneratorTest < Rails::Generators::TestCase
@@ -68,8 +120,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
   def test_generating_without_options
     run_generator
     assert_file "README.md", /Bukkits/
-    assert_no_file "config/routes.rb"
-    assert_no_file "app/assets/config/bukkits_manifest.js"
     assert_file "test/test_helper.rb" do |content|
       assert_match(/require_relative.+test\/dummy\/config\/environment/, content)
       assert_match(/ActiveRecord::Migrator\.migrations_paths.+test\/dummy\/db\/migrate/, content)
@@ -83,13 +133,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
       assert_match(/class BukkitsTest < ActiveSupport::TestCase/, content)
       assert_match(/assert Bukkits::VERSION/, content)
     end
-    assert_file "bin/test"
-    assert_no_file "bin/rails"
-  end
-
-  def test_initializes_git_repo
-    run_generator
-    assert_directory ".git"
   end
 
   def test_initializes_git_repo_with_main_branch_without_user_default
@@ -141,11 +184,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "test/integration/navigation_test.rb", /ActionDispatch::IntegrationTest/
   end
 
-  def test_inclusion_of_git_source
-    run_generator [destination_root]
-    assert_file "Gemfile", /git_source/
-  end
-
   def test_inclusion_of_a_debugger
     run_generator [destination_root, "--full"]
     if defined?(JRUBY_VERSION)
@@ -176,12 +214,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "bin/rails", /APP_PATH/
   end
 
-  def test_generating_adds_dummy_app_without_javascript_and_assets_deps
-    run_generator
-
-    assert_file "test/dummy/app/assets/stylesheets/application.css"
-  end
-
   def test_ensure_that_plugin_options_are_not_passed_to_app_generator
     FileUtils.cd(fixtures_root)
     assert_no_match(/It works from file!.*It works_from_file/, run_generator([destination_root, "-m", "lib/template.rb"]))
@@ -204,11 +236,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
   def test_default_database_dependency_is_sqlite
     run_generator
     assert_file "test/dummy/config/database.yml", /sqlite/
-    if defined?(JRUBY_VERSION)
-      assert_gem "activerecord-jdbcsqlite3-adapter"
-    else
-      assert_gem "sqlite3"
-    end
+    assert_gem "sqlite3"
   end
 
   def test_custom_database_dependency
@@ -217,13 +245,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "Gemfile", /mysql/
   end
 
-  def test_skip_database_dependency
-    run_generator [destination_root, "--skip-active-record"]
-    assert_file "Gemfile" do |contents|
-      assert_no_match(/sqlite/, contents)
-    end
-  end
-
   def test_ensure_that_skip_active_record_option_is_passed_to_app_generator
     run_generator [destination_root, "--skip_active_record"]
     assert_file "test/test_helper.rb" do |contents|
@@ -244,7 +265,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     end
   end
 
-  def test_generation_runs_bundle_install
+  def test_generation_does_not_run_bundle_install
     generator([destination_root])
     run_generator_instance
 
@@ -284,7 +305,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     in_plugin_context(destination_root) do
       quietly { system "bundle install" }
       output = `bin/rails db:migrate 2>&1`
-      assert $?.success?, "Command failed: #{output}"
+      assert_predicate $?, :success?, "Command failed: #{output}"
     end
   end
 
@@ -374,7 +395,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_no_file "bin/test"
   end
 
-  def test_create_mountable_application_with_mountable_option_and_hypenated_name
+  def test_create_mountable_application_with_mountable_option_and_hyphenated_name
     run_generator [File.join(destination_root, "hyphenated-name"), "--mountable"]
     assert_no_file "hyphenated-name/app/assets/javascripts/hyphenated/name"
     assert_file "hyphenated-name/app/assets/stylesheets/hyphenated/name"
@@ -396,7 +417,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     end
   end
 
-  def test_create_mountable_application_with_mountable_option_and_hypenated_and_underscored_name
+  def test_create_mountable_application_with_mountable_option_and_hyphenated_and_underscored_name
     run_generator [File.join(destination_root, "my_hyphenated-name"), "--mountable"]
     assert_no_file "my_hyphenated-name/app/assets/javascripts/my_hyphenated/name"
     assert_file "my_hyphenated-name/app/assets/stylesheets/my_hyphenated/name"
@@ -418,7 +439,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     end
   end
 
-  def test_create_mountable_application_with_mountable_option_and_multiple_hypenates_in_name
+  def test_create_mountable_application_with_mountable_option_and_multiple_hyphenates_in_name
     run_generator [File.join(destination_root, "deep-hyphenated-name"), "--mountable"]
     assert_no_file "deep-hyphenated-name/app/assets/javascripts/deep/hyphenated/name"
     assert_file "deep-hyphenated-name/app/assets/stylesheets/deep/hyphenated/name"
@@ -560,7 +581,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
 
     in_plugin_context(destination_root) do
       output = `bin/test 2>&1`
-      assert $?.success?, "Command failed: #{output}"
+      assert_predicate $?, :success?, "Command failed: #{output}"
     end
   end
 
@@ -608,24 +629,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     end
   end
 
-  def test_unnecessary_files_are_not_generated_in_dummy_application
-    run_generator
-    assert_no_file "test/dummy/.gitignore"
-    assert_no_file "test/dummy/.ruby-version"
-    assert_no_file "test/dummy/db/seeds.rb"
-    assert_no_file "test/dummy/Gemfile"
-    assert_no_file "test/dummy/public/robots.txt"
-    assert_no_file "test/dummy/README.md"
-    assert_no_file "test/dummy/config/master.key"
-    assert_no_file "test/dummy/config/credentials.yml.enc"
-    assert_no_file "test/dummy/Dockerfile"
-    assert_no_file "test/dummy/.dockerignore"
-    assert_no_directory "test/dummy/lib/tasks"
-    assert_no_directory "test/dummy/test"
-    assert_no_directory "test/dummy/vendor"
-    assert_no_directory "test/dummy/.git"
-  end
-
   def test_skipping_test_files
     run_generator [destination_root, "--skip-test"]
     assert_no_directory "test"
@@ -637,7 +640,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
   def test_dummy_application_skips_asset_pipeline_when_simple_railtie
     run_generator
 
-    assert_no_gem "sprockets-rails"
+    assert_no_gem "propshaft"
     assert_no_file "test/dummy/config/initializers/assets.rb"
     assert_file "test/dummy/config/environments/development.rb" do |content|
       assert_no_match "config.assets", content
@@ -647,33 +650,25 @@ class PluginGeneratorTest < Rails::Generators::TestCase
   def test_dummy_application_configures_asset_pipeline_when_mountable
     run_generator [destination_root, "--mountable"]
 
-    assert_gem "sprockets-rails"
-    assert_file "test/dummy/app/assets/config/manifest.js"
+    assert_gem "propshaft"
+    assert_file "test/dummy/config/initializers/assets.rb"
   end
 
   def test_dummy_application_configures_asset_pipeline_when_full
     run_generator [destination_root, "--full"]
 
-    assert_gem "sprockets-rails"
-    assert_file "test/dummy/app/assets/config/manifest.js"
-  end
-
-  def test_dummy_application_skips_asset_pipeline_when_flag_skip_asset_pipeline
-    run_generator [destination_root, "--mountable", "--skip-asset-pipeline"]
-
-    assert_no_gem "sprockets-rails"
-    assert_no_file "test/dummy/config/initializers/assets.rb"
+    assert_gem "propshaft"
+    assert_file "test/dummy/config/initializers/assets.rb"
     assert_file "test/dummy/config/environments/development.rb" do |content|
       assert_no_match "config.assets", content
     end
   end
 
-  def test_dummy_application_respects_asset_pipeline_gem_choice
-    run_generator [destination_root, "--mountable", "--asset-pipeline=propshaft"]
+  def test_dummy_application_skips_asset_pipeline_when_flag_skip_asset_pipeline
+    run_generator [destination_root, "--mountable", "--skip-asset-pipeline"]
 
-    assert_gem "propshaft"
-    assert_no_gem "sprockets-rails"
-    assert_file "test/dummy/config/initializers/assets.rb"
+    assert_no_gem "propshaft"
+    assert_no_file "test/dummy/config/initializers/assets.rb"
     assert_file "test/dummy/config/environments/development.rb" do |content|
       assert_no_match "config.assets", content
     end
@@ -682,7 +677,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
   def test_no_asset_pipeline_gem_when_no_dummy_application
     run_generator [destination_root, "--mountable", "--skip-test"]
 
-    assert_no_gem "sprockets-rails"
+    assert_no_gem "propshaft"
     assert_no_directory "test/dummy"
   end
 
@@ -710,7 +705,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
 
       run_generator
 
-      assert_file gemfile_path, /^gem 'bukkits', path: 'tmp\/bukkits'/
+      assert_file gemfile_path, /^gem "bukkits", path: "tmp\/bukkits"/
     end
   end
 
@@ -719,7 +714,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
       FileUtils.cd(destination_root)
       run_generator ["bukkits"]
 
-      assert_file gemfile_path, /gem 'bukkits', path: 'bukkits'/
+      assert_file gemfile_path, /gem "bukkits", path: "bukkits"/
     end
   end
 
@@ -728,7 +723,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
       run_generator [destination_root, "--skip-gemfile-entry"]
 
       assert_file gemfile_path do |contents|
-        assert_no_match(/gem 'bukkits', path: 'tmp\/bukkits'/, contents)
+        assert_no_match(/gem "bukkits", path: "tmp\/bukkits"/, contents)
       end
     end
   end
@@ -920,6 +915,21 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     Object.send(:remove_const, "ENGINE_ROOT")
   end
 
+  def test_railtie_test_command
+    run_generator [destination_root]
+    assert_file ".github/workflows/ci.yml", /run: bin\/test/
+  end
+
+  def test_engine_test_command
+    run_generator [destination_root, "--full"]
+    assert_file ".github/workflows/ci.yml", /run: bin\/rails db:test:prepare test/
+  end
+
+  def test_engine_without_active_record_test_command
+    run_generator [destination_root, "--full", "--skip-active-record"]
+    assert_file ".github/workflows/ci.yml", /run: bin\/rails test/
+  end
+
   private
     def action(*args, &block)
       silence(:stdout) { generator.send(*args, &block) }
