@@ -57,7 +57,7 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
       end
 
       assert_instance_method :set_product_line, content do |m|
-        assert_match(/@product_line = ProductLine\.find\(params\[:id\]\)/, m)
+        assert_match(/@product_line = ProductLine\.find\(params\.expect\(:id\)\)/, m)
       end
     end
 
@@ -170,8 +170,8 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
     assert_file "test/controllers/product_lines_controller_test.rb" do |content|
       assert_match(/class ProductLinesControllerTest < ActionDispatch::IntegrationTest/, content)
       assert_match(/test "should get index"/, content)
-      assert_match(/post product_lines_url, params: \{ product_line: \{  \} \}/, content)
-      assert_match(/patch product_line_url\(@product_line\), params: \{ product_line: \{  \} \}/, content)
+      assert_match(/post product_lines_url, params: \{ product_line: \{\} \}/, content)
+      assert_match(/patch product_line_url\(@product_line\), params: \{ product_line: \{\} \}/, content)
     end
   end
 
@@ -260,7 +260,7 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
       end
 
       assert_instance_method :set_admin_role, content do |m|
-        assert_match(/@admin_role = Admin::Role\.find\(params\[:id\]\)/, m)
+        assert_match(/@admin_role = Admin::Role\.find\(params\.expect\(:id\)\)/, m)
       end
     end
 
@@ -363,9 +363,11 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
     route_path = File.expand_path("config/routes.rb", destination_root)
     content = File.read(route_path)
 
-    # Remove all of the comments, blank lines, and default health controller from the routes file
+    # Remove all of the comments, blank lines, and default actions from the routes file
     content.gsub!(/^  \#.*\n/, "")
     content.gsub!(/^  get "up".*\n/, "")
+    content.gsub!(/^  get "service-worker".*\n/, "")
+    content.gsub!(/^  get "manifest".*\n/, "")
     content.gsub!(/^\n/, "")
 
     File.write(route_path, content)
@@ -428,7 +430,7 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
 
     assert_file "app/controllers/accounts_controller.rb" do |content|
       assert_instance_method :account_params, content do |m|
-        assert_match(/permit\(:name, :currency_id, :user_id\)/, m)
+        assert_match(/expect\(account: \[ :name, :currency_id, :user_id \]\)/, m)
       end
     end
 
@@ -459,7 +461,7 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
 
     assert_file "app/controllers/messages_controller.rb" do |content|
       assert_instance_method :message_params, content do |m|
-        assert_match(/permit\(:video, photos: \[\], images: \[\]\)/, m)
+        assert_match(/expect\(message: \[ :video, photos: \[\], images: \[\] \]\)/, m)
       end
     end
 
@@ -486,12 +488,12 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
 
     assert_file "app/controllers/messages_controller.rb" do |content|
       assert_instance_method :message_params, content do |m|
-        assert_match(/permit\(:content\)/, m)
+        assert_match(/expect\(message: \[ :content \]\)/, m)
       end
     end
 
     assert_file "app/views/messages/_form.html.erb" do |content|
-      assert_match(/^\W{4}<%= form\.rich_text_area :content %>/, content)
+      assert_match(/^\W{4}<%= form\.rich_textarea :content %>/, content)
     end
 
     assert_file "test/system/messages_test.rb" do |content|
@@ -534,7 +536,7 @@ class ScaffoldGeneratorTest < Rails::Generators::TestCase
 
     assert_file "app/controllers/users_controller.rb" do |content|
       assert_instance_method :user_params, content do |m|
-        assert_match(/permit\(:name, :password, :password_confirmation\)/, m)
+        assert_match(/expect\(user: \[ :name, :password, :password_confirmation \]\)/, m)
       end
     end
 
