@@ -13,9 +13,6 @@ module RailsStrictWarnings # :nodoc:
     # Expected non-verbose warning emitted by Rails.
     /Ignoring .*\.yml because it has expired/,
     /Failed to validate the schema cache because/,
-
-    # TODO: We need to decide what to do with this.
-    /Status code :unprocessable_entity is deprecated/,
   )
 
   SUPPRESSED_WARNINGS = Regexp.union(
